/* PreferencesWindow.c generated by valac 0.56.19, the Vala compiler
 * generated from PreferencesWindow.vala, do not modify */

/*
 * Copyright © 2025 Alain M. (https://github.com/alainm23/planify)
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public
 * License as published by the Free Software Foundation; either
 * version 3 of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public
 * License along with this program; if not, write to the
 * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
 * Boston, MA 02110-1301 USA
 *
 * Authored by: Alain M. <alainmh23@gmail.com>
 */

#include <adwaita.h>
#include <glib-object.h>
#include <gee.h>
#include <glib.h>
#include <stdlib.h>
#include <string.h>
#include <gtk/gtk.h>
#include <gio/gio.h>
#include <glib/gi18n-lib.h>
#include "planify.h"
#include <float.h>
#include <math.h>
#include <gdk/gdk.h>

#if !defined(VALA_STRICT_C)
#if !defined(__clang__) && defined(__GNUC__) && (__GNUC__ >= 14)
#pragma GCC diagnostic warning "-Wincompatible-pointer-types"
#elif defined(__clang__) && (__clang_major__ >= 16)
#pragma clang diagnostic ignored "-Wincompatible-function-pointer-types"
#pragma clang diagnostic ignored "-Wincompatible-pointer-types"
#endif
#endif
#if !defined(VALA_EXTERN)
#if defined(_MSC_VER)
#define VALA_EXTERN __declspec(dllexport) extern
#elif __GNUC__ >= 4
#define VALA_EXTERN __attribute__((visibility("default"))) extern
#else
#define VALA_EXTERN extern
#endif
#endif

#define DIALOGS_PREFERENCES_TYPE_PREFERENCES_WINDOW (dialogs_preferences_preferences_window_get_type ())
#define DIALOGS_PREFERENCES_PREFERENCES_WINDOW(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), DIALOGS_PREFERENCES_TYPE_PREFERENCES_WINDOW, DialogsPreferencesPreferencesWindow))
#define DIALOGS_PREFERENCES_PREFERENCES_WINDOW_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), DIALOGS_PREFERENCES_TYPE_PREFERENCES_WINDOW, DialogsPreferencesPreferencesWindowClass))
#define DIALOGS_PREFERENCES_IS_PREFERENCES_WINDOW(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), DIALOGS_PREFERENCES_TYPE_PREFERENCES_WINDOW))
#define DIALOGS_PREFERENCES_IS_PREFERENCES_WINDOW_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), DIALOGS_PREFERENCES_TYPE_PREFERENCES_WINDOW))
#define DIALOGS_PREFERENCES_PREFERENCES_WINDOW_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), DIALOGS_PREFERENCES_TYPE_PREFERENCES_WINDOW, DialogsPreferencesPreferencesWindowClass))

typedef struct _DialogsPreferencesPreferencesWindow DialogsPreferencesPreferencesWindow;
typedef struct _DialogsPreferencesPreferencesWindowClass DialogsPreferencesPreferencesWindowClass;
typedef struct _DialogsPreferencesPreferencesWindowPrivate DialogsPreferencesPreferencesWindowPrivate;

#define DIALOGS_PREFERENCES_PAGES_TYPE_BASE_PAGE (dialogs_preferences_pages_base_page_get_type ())
#define DIALOGS_PREFERENCES_PAGES_BASE_PAGE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), DIALOGS_PREFERENCES_PAGES_TYPE_BASE_PAGE, DialogsPreferencesPagesBasePage))
#define DIALOGS_PREFERENCES_PAGES_BASE_PAGE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), DIALOGS_PREFERENCES_PAGES_TYPE_BASE_PAGE, DialogsPreferencesPagesBasePageClass))
#define DIALOGS_PREFERENCES_PAGES_IS_BASE_PAGE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), DIALOGS_PREFERENCES_PAGES_TYPE_BASE_PAGE))
#define DIALOGS_PREFERENCES_PAGES_IS_BASE_PAGE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), DIALOGS_PREFERENCES_PAGES_TYPE_BASE_PAGE))
#define DIALOGS_PREFERENCES_PAGES_BASE_PAGE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), DIALOGS_PREFERENCES_PAGES_TYPE_BASE_PAGE, DialogsPreferencesPagesBasePageClass))

typedef struct _DialogsPreferencesPagesBasePage DialogsPreferencesPagesBasePage;
typedef struct _DialogsPreferencesPagesBasePageClass DialogsPreferencesPagesBasePageClass;
enum  {
	DIALOGS_PREFERENCES_PREFERENCES_WINDOW_0_PROPERTY,
	DIALOGS_PREFERENCES_PREFERENCES_WINDOW_NUM_PROPERTIES
};
static GParamSpec* dialogs_preferences_preferences_window_properties[DIALOGS_PREFERENCES_PREFERENCES_WINDOW_NUM_PROPERTIES];
#define _g_object_unref0(var) ((var == NULL) ? NULL : (var = (g_object_unref (var), NULL)))

#define DIALOGS_PREFERENCES_PAGES_TYPE_ACCOUNTS (dialogs_preferences_pages_accounts_get_type ())
#define DIALOGS_PREFERENCES_PAGES_ACCOUNTS(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), DIALOGS_PREFERENCES_PAGES_TYPE_ACCOUNTS, DialogsPreferencesPagesAccounts))
#define DIALOGS_PREFERENCES_PAGES_ACCOUNTS_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), DIALOGS_PREFERENCES_PAGES_TYPE_ACCOUNTS, DialogsPreferencesPagesAccountsClass))
#define DIALOGS_PREFERENCES_PAGES_IS_ACCOUNTS(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), DIALOGS_PREFERENCES_PAGES_TYPE_ACCOUNTS))
#define DIALOGS_PREFERENCES_PAGES_IS_ACCOUNTS_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), DIALOGS_PREFERENCES_PAGES_TYPE_ACCOUNTS))
#define DIALOGS_PREFERENCES_PAGES_ACCOUNTS_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), DIALOGS_PREFERENCES_PAGES_TYPE_ACCOUNTS, DialogsPreferencesPagesAccountsClass))

typedef struct _DialogsPreferencesPagesAccounts DialogsPreferencesPagesAccounts;
typedef struct _DialogsPreferencesPagesAccountsClass DialogsPreferencesPagesAccountsClass;

#define DIALOGS_PREFERENCES_PAGES_TYPE_HOME_VIEW (dialogs_preferences_pages_home_view_get_type ())
#define DIALOGS_PREFERENCES_PAGES_HOME_VIEW(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), DIALOGS_PREFERENCES_PAGES_TYPE_HOME_VIEW, DialogsPreferencesPagesHomeView))
#define DIALOGS_PREFERENCES_PAGES_HOME_VIEW_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), DIALOGS_PREFERENCES_PAGES_TYPE_HOME_VIEW, DialogsPreferencesPagesHomeViewClass))
#define DIALOGS_PREFERENCES_PAGES_IS_HOME_VIEW(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), DIALOGS_PREFERENCES_PAGES_TYPE_HOME_VIEW))
#define DIALOGS_PREFERENCES_PAGES_IS_HOME_VIEW_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), DIALOGS_PREFERENCES_PAGES_TYPE_HOME_VIEW))
#define DIALOGS_PREFERENCES_PAGES_HOME_VIEW_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), DIALOGS_PREFERENCES_PAGES_TYPE_HOME_VIEW, DialogsPreferencesPagesHomeViewClass))

typedef struct _DialogsPreferencesPagesHomeView DialogsPreferencesPagesHomeView;
typedef struct _DialogsPreferencesPagesHomeViewClass DialogsPreferencesPagesHomeViewClass;

#define DIALOGS_PREFERENCES_PAGES_TYPE_APPEARANCE (dialogs_preferences_pages_appearance_get_type ())
#define DIALOGS_PREFERENCES_PAGES_APPEARANCE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), DIALOGS_PREFERENCES_PAGES_TYPE_APPEARANCE, DialogsPreferencesPagesAppearance))
#define DIALOGS_PREFERENCES_PAGES_APPEARANCE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), DIALOGS_PREFERENCES_PAGES_TYPE_APPEARANCE, DialogsPreferencesPagesAppearanceClass))
#define DIALOGS_PREFERENCES_PAGES_IS_APPEARANCE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), DIALOGS_PREFERENCES_PAGES_TYPE_APPEARANCE))
#define DIALOGS_PREFERENCES_PAGES_IS_APPEARANCE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), DIALOGS_PREFERENCES_PAGES_TYPE_APPEARANCE))
#define DIALOGS_PREFERENCES_PAGES_APPEARANCE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), DIALOGS_PREFERENCES_PAGES_TYPE_APPEARANCE, DialogsPreferencesPagesAppearanceClass))

typedef struct _DialogsPreferencesPagesAppearance DialogsPreferencesPagesAppearance;
typedef struct _DialogsPreferencesPagesAppearanceClass DialogsPreferencesPagesAppearanceClass;

#define DIALOGS_PREFERENCES_PAGES_TYPE_BACKUP (dialogs_preferences_pages_backup_get_type ())
#define DIALOGS_PREFERENCES_PAGES_BACKUP(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), DIALOGS_PREFERENCES_PAGES_TYPE_BACKUP, DialogsPreferencesPagesBackup))
#define DIALOGS_PREFERENCES_PAGES_BACKUP_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), DIALOGS_PREFERENCES_PAGES_TYPE_BACKUP, DialogsPreferencesPagesBackupClass))
#define DIALOGS_PREFERENCES_PAGES_IS_BACKUP(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), DIALOGS_PREFERENCES_PAGES_TYPE_BACKUP))
#define DIALOGS_PREFERENCES_PAGES_IS_BACKUP_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), DIALOGS_PREFERENCES_PAGES_TYPE_BACKUP))
#define DIALOGS_PREFERENCES_PAGES_BACKUP_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), DIALOGS_PREFERENCES_PAGES_TYPE_BACKUP, DialogsPreferencesPagesBackupClass))

typedef struct _DialogsPreferencesPagesBackup DialogsPreferencesPagesBackup;
typedef struct _DialogsPreferencesPagesBackupClass DialogsPreferencesPagesBackupClass;

#define DIALOGS_PREFERENCES_PAGES_TYPE_SIDEBAR (dialogs_preferences_pages_sidebar_get_type ())
#define DIALOGS_PREFERENCES_PAGES_SIDEBAR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), DIALOGS_PREFERENCES_PAGES_TYPE_SIDEBAR, DialogsPreferencesPagesSidebar))
#define DIALOGS_PREFERENCES_PAGES_SIDEBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), DIALOGS_PREFERENCES_PAGES_TYPE_SIDEBAR, DialogsPreferencesPagesSidebarClass))
#define DIALOGS_PREFERENCES_PAGES_IS_SIDEBAR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), DIALOGS_PREFERENCES_PAGES_TYPE_SIDEBAR))
#define DIALOGS_PREFERENCES_PAGES_IS_SIDEBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), DIALOGS_PREFERENCES_PAGES_TYPE_SIDEBAR))
#define DIALOGS_PREFERENCES_PAGES_SIDEBAR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), DIALOGS_PREFERENCES_PAGES_TYPE_SIDEBAR, DialogsPreferencesPagesSidebarClass))

typedef struct _DialogsPreferencesPagesSidebar DialogsPreferencesPagesSidebar;
typedef struct _DialogsPreferencesPagesSidebarClass DialogsPreferencesPagesSidebarClass;

#define DIALOGS_PREFERENCES_PAGES_TYPE_GENERAL (dialogs_preferences_pages_general_get_type ())
#define DIALOGS_PREFERENCES_PAGES_GENERAL(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), DIALOGS_PREFERENCES_PAGES_TYPE_GENERAL, DialogsPreferencesPagesGeneral))
#define DIALOGS_PREFERENCES_PAGES_GENERAL_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), DIALOGS_PREFERENCES_PAGES_TYPE_GENERAL, DialogsPreferencesPagesGeneralClass))
#define DIALOGS_PREFERENCES_PAGES_IS_GENERAL(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), DIALOGS_PREFERENCES_PAGES_TYPE_GENERAL))
#define DIALOGS_PREFERENCES_PAGES_IS_GENERAL_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), DIALOGS_PREFERENCES_PAGES_TYPE_GENERAL))
#define DIALOGS_PREFERENCES_PAGES_GENERAL_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), DIALOGS_PREFERENCES_PAGES_TYPE_GENERAL, DialogsPreferencesPagesGeneralClass))

typedef struct _DialogsPreferencesPagesGeneral DialogsPreferencesPagesGeneral;
typedef struct _DialogsPreferencesPagesGeneralClass DialogsPreferencesPagesGeneralClass;

#define DIALOGS_PREFERENCES_PAGES_TYPE_TASK_SETTING (dialogs_preferences_pages_task_setting_get_type ())
#define DIALOGS_PREFERENCES_PAGES_TASK_SETTING(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), DIALOGS_PREFERENCES_PAGES_TYPE_TASK_SETTING, DialogsPreferencesPagesTaskSetting))
#define DIALOGS_PREFERENCES_PAGES_TASK_SETTING_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), DIALOGS_PREFERENCES_PAGES_TYPE_TASK_SETTING, DialogsPreferencesPagesTaskSettingClass))
#define DIALOGS_PREFERENCES_PAGES_IS_TASK_SETTING(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), DIALOGS_PREFERENCES_PAGES_TYPE_TASK_SETTING))
#define DIALOGS_PREFERENCES_PAGES_IS_TASK_SETTING_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), DIALOGS_PREFERENCES_PAGES_TYPE_TASK_SETTING))
#define DIALOGS_PREFERENCES_PAGES_TASK_SETTING_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), DIALOGS_PREFERENCES_PAGES_TYPE_TASK_SETTING, DialogsPreferencesPagesTaskSettingClass))

typedef struct _DialogsPreferencesPagesTaskSetting DialogsPreferencesPagesTaskSetting;
typedef struct _DialogsPreferencesPagesTaskSettingClass DialogsPreferencesPagesTaskSettingClass;

#define DIALOGS_PREFERENCES_PAGES_TYPE_QUICK_ADD (dialogs_preferences_pages_quick_add_get_type ())
#define DIALOGS_PREFERENCES_PAGES_QUICK_ADD(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), DIALOGS_PREFERENCES_PAGES_TYPE_QUICK_ADD, DialogsPreferencesPagesQuickAdd))
#define DIALOGS_PREFERENCES_PAGES_QUICK_ADD_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), DIALOGS_PREFERENCES_PAGES_TYPE_QUICK_ADD, DialogsPreferencesPagesQuickAddClass))
#define DIALOGS_PREFERENCES_PAGES_IS_QUICK_ADD(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), DIALOGS_PREFERENCES_PAGES_TYPE_QUICK_ADD))
#define DIALOGS_PREFERENCES_PAGES_IS_QUICK_ADD_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), DIALOGS_PREFERENCES_PAGES_TYPE_QUICK_ADD))
#define DIALOGS_PREFERENCES_PAGES_QUICK_ADD_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), DIALOGS_PREFERENCES_PAGES_TYPE_QUICK_ADD, DialogsPreferencesPagesQuickAddClass))

typedef struct _DialogsPreferencesPagesQuickAdd DialogsPreferencesPagesQuickAdd;
typedef struct _DialogsPreferencesPagesQuickAddClass DialogsPreferencesPagesQuickAddClass;

#define DIALOGS_PREFERENCES_PAGES_TYPE_DONATE (dialogs_preferences_pages_donate_get_type ())
#define DIALOGS_PREFERENCES_PAGES_DONATE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), DIALOGS_PREFERENCES_PAGES_TYPE_DONATE, DialogsPreferencesPagesDonate))
#define DIALOGS_PREFERENCES_PAGES_DONATE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), DIALOGS_PREFERENCES_PAGES_TYPE_DONATE, DialogsPreferencesPagesDonateClass))
#define DIALOGS_PREFERENCES_PAGES_IS_DONATE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), DIALOGS_PREFERENCES_PAGES_TYPE_DONATE))
#define DIALOGS_PREFERENCES_PAGES_IS_DONATE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), DIALOGS_PREFERENCES_PAGES_TYPE_DONATE))
#define DIALOGS_PREFERENCES_PAGES_DONATE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), DIALOGS_PREFERENCES_PAGES_TYPE_DONATE, DialogsPreferencesPagesDonateClass))

typedef struct _DialogsPreferencesPagesDonate DialogsPreferencesPagesDonate;
typedef struct _DialogsPreferencesPagesDonateClass DialogsPreferencesPagesDonateClass;

#define WIDGETS_TYPE_TRANSLATION_ROW (widgets_translation_row_get_type ())
#define WIDGETS_TRANSLATION_ROW(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), WIDGETS_TYPE_TRANSLATION_ROW, WidgetsTranslationRow))
#define WIDGETS_TRANSLATION_ROW_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), WIDGETS_TYPE_TRANSLATION_ROW, WidgetsTranslationRowClass))
#define WIDGETS_IS_TRANSLATION_ROW(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), WIDGETS_TYPE_TRANSLATION_ROW))
#define WIDGETS_IS_TRANSLATION_ROW_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), WIDGETS_TYPE_TRANSLATION_ROW))
#define WIDGETS_TRANSLATION_ROW_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), WIDGETS_TYPE_TRANSLATION_ROW, WidgetsTranslationRowClass))

typedef struct _WidgetsTranslationRow WidgetsTranslationRow;
typedef struct _WidgetsTranslationRowClass WidgetsTranslationRowClass;
typedef struct _Block94Data Block94Data;
#define _g_free0(var) (var = (g_free (var), NULL))
#define _g_error_free0(var) ((var == NULL) ? NULL : (var = (g_error_free (var), NULL)))

#define TYPE_PLANIFY (planify_get_type ())
#define PLANIFY(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_PLANIFY, Planify))
#define PLANIFY_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_PLANIFY, PlanifyClass))
#define IS_PLANIFY(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_PLANIFY))
#define IS_PLANIFY_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_PLANIFY))
#define PLANIFY_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_PLANIFY, PlanifyClass))

typedef struct _Planify Planify;
typedef struct _PlanifyClass PlanifyClass;
typedef struct _PlanifyPrivate PlanifyPrivate;

#define TYPE_MAIN_WINDOW (main_window_get_type ())
#define MAIN_WINDOW(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_MAIN_WINDOW, MainWindow))
#define MAIN_WINDOW_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_MAIN_WINDOW, MainWindowClass))
#define IS_MAIN_WINDOW(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_MAIN_WINDOW))
#define IS_MAIN_WINDOW_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_MAIN_WINDOW))
#define MAIN_WINDOW_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_MAIN_WINDOW, MainWindowClass))

typedef struct _MainWindow MainWindow;
typedef struct _MainWindowClass MainWindowClass;

struct _DialogsPreferencesPreferencesWindow {
	AdwPreferencesDialog parent_instance;
	DialogsPreferencesPreferencesWindowPrivate * priv;
	GeeHashMap* signal_map;
};

struct _DialogsPreferencesPreferencesWindowClass {
	AdwPreferencesDialogClass parent_class;
};

struct _DialogsPreferencesPreferencesWindowPrivate {
	GeeHashMap* page_map;
	GtkShortcutController* shortcut_controller;
};

struct _Block94Data {
	int _ref_count_;
	DialogsPreferencesPreferencesWindow* self;
	WidgetsTranslationRow* translation_row;
};

struct _Planify {
	AdwApplication parent_instance;
	PlanifyPrivate * priv;
	MainWindow* main_window;
};

struct _PlanifyClass {
	AdwApplicationClass parent_class;
};

static gint DialogsPreferencesPreferencesWindow_private_offset;
static gpointer dialogs_preferences_preferences_window_parent_class = NULL;

VALA_EXTERN GType dialogs_preferences_preferences_window_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (DialogsPreferencesPreferencesWindow, g_object_unref)
VALA_EXTERN GType dialogs_preferences_pages_base_page_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (DialogsPreferencesPagesBasePage, g_object_unref)
VALA_EXTERN DialogsPreferencesPreferencesWindow* dialogs_preferences_preferences_window_new (void);
VALA_EXTERN DialogsPreferencesPreferencesWindow* dialogs_preferences_preferences_window_construct (GType object_type);
static GtkWidget* dialogs_preferences_preferences_window_generate_icon (DialogsPreferencesPreferencesWindow* self,
                                                                 const gchar* icon_name,
                                                                 gint size);
static AdwNavigationPage* dialogs_preferences_preferences_window_build_page (DialogsPreferencesPreferencesWindow* self,
                                                                      const gchar* page);
VALA_EXTERN DialogsPreferencesPagesAccounts* dialogs_preferences_pages_accounts_new (AdwPreferencesDialog* preferences_dialog);
VALA_EXTERN DialogsPreferencesPagesAccounts* dialogs_preferences_pages_accounts_construct (GType object_type,
                                                                               AdwPreferencesDialog* preferences_dialog);
VALA_EXTERN GType dialogs_preferences_pages_accounts_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (DialogsPreferencesPagesAccounts, g_object_unref)
VALA_EXTERN DialogsPreferencesPagesHomeView* dialogs_preferences_pages_home_view_new (AdwPreferencesDialog* preferences_dialog);
VALA_EXTERN DialogsPreferencesPagesHomeView* dialogs_preferences_pages_home_view_construct (GType object_type,
                                                                                AdwPreferencesDialog* preferences_dialog);
VALA_EXTERN GType dialogs_preferences_pages_home_view_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (DialogsPreferencesPagesHomeView, g_object_unref)
VALA_EXTERN DialogsPreferencesPagesAppearance* dialogs_preferences_pages_appearance_new (AdwPreferencesDialog* preferences_dialog);
VALA_EXTERN DialogsPreferencesPagesAppearance* dialogs_preferences_pages_appearance_construct (GType object_type,
                                                                                   AdwPreferencesDialog* preferences_dialog);
VALA_EXTERN GType dialogs_preferences_pages_appearance_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (DialogsPreferencesPagesAppearance, g_object_unref)
VALA_EXTERN DialogsPreferencesPagesBackup* dialogs_preferences_pages_backup_new (AdwPreferencesDialog* preferences_dialog);
VALA_EXTERN DialogsPreferencesPagesBackup* dialogs_preferences_pages_backup_construct (GType object_type,
                                                                           AdwPreferencesDialog* preferences_dialog);
VALA_EXTERN GType dialogs_preferences_pages_backup_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (DialogsPreferencesPagesBackup, g_object_unref)
VALA_EXTERN DialogsPreferencesPagesSidebar* dialogs_preferences_pages_sidebar_new (AdwPreferencesDialog* preferences_dialog);
VALA_EXTERN DialogsPreferencesPagesSidebar* dialogs_preferences_pages_sidebar_construct (GType object_type,
                                                                             AdwPreferencesDialog* preferences_dialog);
VALA_EXTERN GType dialogs_preferences_pages_sidebar_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (DialogsPreferencesPagesSidebar, g_object_unref)
VALA_EXTERN DialogsPreferencesPagesGeneral* dialogs_preferences_pages_general_new (AdwPreferencesDialog* preferences_dialog);
VALA_EXTERN DialogsPreferencesPagesGeneral* dialogs_preferences_pages_general_construct (GType object_type,
                                                                             AdwPreferencesDialog* preferences_dialog);
VALA_EXTERN GType dialogs_preferences_pages_general_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (DialogsPreferencesPagesGeneral, g_object_unref)
VALA_EXTERN DialogsPreferencesPagesTaskSetting* dialogs_preferences_pages_task_setting_new (AdwPreferencesDialog* preferences_dialog);
VALA_EXTERN DialogsPreferencesPagesTaskSetting* dialogs_preferences_pages_task_setting_construct (GType object_type,
                                                                                      AdwPreferencesDialog* preferences_dialog);
VALA_EXTERN GType dialogs_preferences_pages_task_setting_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (DialogsPreferencesPagesTaskSetting, g_object_unref)
VALA_EXTERN DialogsPreferencesPagesQuickAdd* dialogs_preferences_pages_quick_add_new (AdwPreferencesDialog* preferences_dialog);
VALA_EXTERN DialogsPreferencesPagesQuickAdd* dialogs_preferences_pages_quick_add_construct (GType object_type,
                                                                                AdwPreferencesDialog* preferences_dialog);
VALA_EXTERN GType dialogs_preferences_pages_quick_add_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (DialogsPreferencesPagesQuickAdd, g_object_unref)
VALA_EXTERN DialogsPreferencesPagesDonate* dialogs_preferences_pages_donate_new (AdwPreferencesDialog* preferences_dialog);
VALA_EXTERN DialogsPreferencesPagesDonate* dialogs_preferences_pages_donate_construct (GType object_type,
                                                                           AdwPreferencesDialog* preferences_dialog);
VALA_EXTERN GType dialogs_preferences_pages_donate_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (DialogsPreferencesPagesDonate, g_object_unref)
VALA_EXTERN void dialogs_preferences_preferences_window_show_page (DialogsPreferencesPreferencesWindow* self,
                                                       const gchar* page_key);
VALA_EXTERN void dialogs_preferences_preferences_window_clean_up (DialogsPreferencesPreferencesWindow* self);
VALA_EXTERN void dialogs_preferences_pages_base_page_clean_up (DialogsPreferencesPagesBasePage* self);
VALA_EXTERN GType widgets_translation_row_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (WidgetsTranslationRow, g_object_unref)
static void dialogs_preferences_preferences_window_setup_visibility_detection (DialogsPreferencesPreferencesWindow* self,
                                                                        WidgetsTranslationRow* translation_row);
static Block94Data* block94_data_ref (Block94Data* _data94_);
static void block94_data_unref (void * _userdata_);
VALA_EXTERN void widgets_translation_row_load_translation_data (WidgetsTranslationRow* self,
                                                    GAsyncReadyCallback _callback_,
                                                    gpointer _user_data_);
VALA_EXTERN void widgets_translation_row_load_translation_data_finish (WidgetsTranslationRow* self,
                                                           GAsyncResult* _res_);
static void __lambda430_ (Block94Data* _data94_);
static gboolean __lambda431_ (Block94Data* _data94_);
VALA_EXTERN void widgets_translation_row_trigger_animation (WidgetsTranslationRow* self);
static gboolean ___lambda431__gsource_func (gpointer self);
static void ___lambda430__gtk_widget_map (GtkWidget* _sender,
                                   gpointer self);
static GObject * dialogs_preferences_preferences_window_constructor (GType type,
                                                              guint n_construct_properties,
                                                              GObjectConstructParam * construct_properties);
static void _dialogs_preferences_preferences_window___lambda432_ (DialogsPreferencesPreferencesWindow* self);
static void __dialogs_preferences_preferences_window___lambda432__adw_action_row_activated (AdwActionRow* _sender,
                                                                                     gpointer self);
static void _dialogs_preferences_preferences_window___lambda433_ (DialogsPreferencesPreferencesWindow* self);
static void __dialogs_preferences_preferences_window___lambda433__adw_action_row_activated (AdwActionRow* _sender,
                                                                                     gpointer self);
static void _dialogs_preferences_preferences_window___lambda434_ (DialogsPreferencesPreferencesWindow* self);
static void __dialogs_preferences_preferences_window___lambda434__adw_action_row_activated (AdwActionRow* _sender,
                                                                                     gpointer self);
static void _dialogs_preferences_preferences_window___lambda435_ (DialogsPreferencesPreferencesWindow* self);
static void __dialogs_preferences_preferences_window___lambda435__adw_action_row_activated (AdwActionRow* _sender,
                                                                                     gpointer self);
static void _dialogs_preferences_preferences_window___lambda436_ (DialogsPreferencesPreferencesWindow* self);
static void __dialogs_preferences_preferences_window___lambda436__adw_action_row_activated (AdwActionRow* _sender,
                                                                                     gpointer self);
static void _dialogs_preferences_preferences_window___lambda437_ (DialogsPreferencesPreferencesWindow* self);
static void __dialogs_preferences_preferences_window___lambda437__adw_action_row_activated (AdwActionRow* _sender,
                                                                                     gpointer self);
static void _dialogs_preferences_preferences_window___lambda438_ (DialogsPreferencesPreferencesWindow* self);
static void __dialogs_preferences_preferences_window___lambda438__adw_action_row_activated (AdwActionRow* _sender,
                                                                                     gpointer self);
static void _dialogs_preferences_preferences_window___lambda439_ (DialogsPreferencesPreferencesWindow* self);
static void __dialogs_preferences_preferences_window___lambda439__adw_action_row_activated (AdwActionRow* _sender,
                                                                                     gpointer self);
static void _dialogs_preferences_preferences_window___lambda440_ (DialogsPreferencesPreferencesWindow* self);
static void __dialogs_preferences_preferences_window___lambda440__adw_action_row_activated (AdwActionRow* _sender,
                                                                                     gpointer self);
VALA_EXTERN WidgetsTranslationRow* widgets_translation_row_new (void);
VALA_EXTERN WidgetsTranslationRow* widgets_translation_row_construct (GType object_type);
VALA_EXTERN void widgets_translation_row_set_icon_name (WidgetsTranslationRow* self,
                                            const gchar* value);
static void _dialogs_preferences_preferences_window___lambda441_ (DialogsPreferencesPreferencesWindow* self);
static void __dialogs_preferences_preferences_window___lambda441__gtk_gesture_click_pressed (GtkGestureClick* _sender,
                                                                                      gint n_press,
                                                                                      gdouble x,
                                                                                      gdouble y,
                                                                                      gpointer self);
static void _dialogs_preferences_preferences_window___lambda442_ (DialogsPreferencesPreferencesWindow* self);
static void __dialogs_preferences_preferences_window___lambda442__adw_action_row_activated (AdwActionRow* _sender,
                                                                                     gpointer self);
static void _dialogs_preferences_preferences_window___lambda443_ (DialogsPreferencesPreferencesWindow* self);
static void __dialogs_preferences_preferences_window___lambda443__adw_action_row_activated (AdwActionRow* _sender,
                                                                                     gpointer self);
static void _dialogs_preferences_preferences_window___lambda444_ (DialogsPreferencesPreferencesWindow* self);
static void __dialogs_preferences_preferences_window___lambda444__adw_action_row_activated (AdwActionRow* _sender,
                                                                                     gpointer self);
static void _dialogs_preferences_preferences_window___lambda445_ (DialogsPreferencesPreferencesWindow* self);
static void __dialogs_preferences_preferences_window___lambda445__adw_action_row_activated (AdwActionRow* _sender,
                                                                                     gpointer self);
static void _dialogs_preferences_preferences_window___lambda446_ (DialogsPreferencesPreferencesWindow* self);
static void __dialogs_preferences_preferences_window___lambda446__adw_action_row_activated (AdwActionRow* _sender,
                                                                                     gpointer self);
static void _dialogs_preferences_preferences_window___lambda447_ (DialogsPreferencesPreferencesWindow* self);
static void __dialogs_preferences_preferences_window___lambda447__adw_action_row_activated (AdwActionRow* _sender,
                                                                                     gpointer self);
static void _dialogs_preferences_preferences_window___lambda448_ (DialogsPreferencesPreferencesWindow* self);
static void __dialogs_preferences_preferences_window___lambda448__adw_action_row_activated (AdwActionRow* _sender,
                                                                                     gpointer self);
static void _dialogs_preferences_preferences_window___lambda449_ (DialogsPreferencesPreferencesWindow* self);
VALA_EXTERN GType planify_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (Planify, g_object_unref)
VALA_EXTERN Planify* planify_get_instance (void);
VALA_EXTERN GType main_window_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (MainWindow, g_object_unref)
static void __dialogs_preferences_preferences_window___lambda449__adw_action_row_activated (AdwActionRow* _sender,
                                                                                     gpointer self);
static gboolean _dialogs_preferences_preferences_window___lambda450_ (DialogsPreferencesPreferencesWindow* self,
                                                               GtkWidget* widget,
                                                               GVariant* args);
static gboolean __dialogs_preferences_preferences_window___lambda450__gtk_shortcut_func (GtkWidget* widget,
                                                                                  GVariant* args,
                                                                                  gpointer self);
static void _dialogs_preferences_preferences_window___lambda451_ (DialogsPreferencesPreferencesWindow* self);
static void __dialogs_preferences_preferences_window___lambda451__adw_dialog_closed (AdwDialog* _sender,
                                                                              gpointer self);
static void dialogs_preferences_preferences_window_finalize (GObject * obj);
static GType dialogs_preferences_preferences_window_get_type_once (void);

static inline gpointer
dialogs_preferences_preferences_window_get_instance_private (DialogsPreferencesPreferencesWindow* self)
{
	return G_STRUCT_MEMBER_P (self, DialogsPreferencesPreferencesWindow_private_offset);
}

DialogsPreferencesPreferencesWindow*
dialogs_preferences_preferences_window_construct (GType object_type)
{
	DialogsPreferencesPreferencesWindow * self = NULL;
	self = (DialogsPreferencesPreferencesWindow*) g_object_new (object_type, "content-width", 450, "content-height", 600, NULL);
	return self;
}

DialogsPreferencesPreferencesWindow*
dialogs_preferences_preferences_window_new (void)
{
	return dialogs_preferences_preferences_window_construct (DIALOGS_PREFERENCES_TYPE_PREFERENCES_WINDOW);
}

static GtkWidget*
dialogs_preferences_preferences_window_generate_icon (DialogsPreferencesPreferencesWindow* self,
                                                      const gchar* icon_name,
                                                      gint size)
{
	GtkImage* _tmp0_ = NULL;
	GtkWidget* result;
	g_return_val_if_fail (self != NULL, NULL);
	g_return_val_if_fail (icon_name != NULL, NULL);
	_tmp0_ = (GtkImage*) gtk_image_new_from_icon_name (icon_name);
	gtk_image_set_pixel_size (_tmp0_, size);
	g_object_ref_sink (_tmp0_);
	result = (GtkWidget*) _tmp0_;
	return result;
}

static AdwNavigationPage*
dialogs_preferences_preferences_window_build_page (DialogsPreferencesPreferencesWindow* self,
                                                   const gchar* page)
{
	GeeHashMap* _tmp0_;
	const gchar* _tmp3_;
	GQuark _tmp5_ = 0U;
	static GQuark _tmp4_label0 = 0;
	static GQuark _tmp4_label1 = 0;
	static GQuark _tmp4_label2 = 0;
	static GQuark _tmp4_label3 = 0;
	static GQuark _tmp4_label4 = 0;
	static GQuark _tmp4_label5 = 0;
	static GQuark _tmp4_label6 = 0;
	static GQuark _tmp4_label7 = 0;
	static GQuark _tmp4_label8 = 0;
	GeeHashMap* _tmp33_;
	gpointer _tmp34_;
	AdwNavigationPage* result;
	g_return_val_if_fail (self != NULL, NULL);
	g_return_val_if_fail (page != NULL, NULL);
	_tmp0_ = self->priv->page_map;
	if (gee_abstract_map_has_key ((GeeAbstractMap*) _tmp0_, page)) {
		GeeHashMap* _tmp1_;
		gpointer _tmp2_;
		_tmp1_ = self->priv->page_map;
		_tmp2_ = gee_abstract_map_get ((GeeAbstractMap*) _tmp1_, page);
		result = (AdwNavigationPage*) ((DialogsPreferencesPagesBasePage*) _tmp2_);
		return result;
	}
	_tmp3_ = page;
	_tmp5_ = (NULL == _tmp3_) ? 0 : g_quark_from_string (_tmp3_);
	if (_tmp5_ == ((0 != _tmp4_label0) ? _tmp4_label0 : (_tmp4_label0 = g_quark_from_static_string ("accounts")))) {
		switch (0) {
			default:
			{
				GeeHashMap* _tmp6_;
				DialogsPreferencesPagesAccounts* _tmp7_;
				DialogsPreferencesPagesAccounts* _tmp8_;
				_tmp6_ = self->priv->page_map;
				_tmp7_ = dialogs_preferences_pages_accounts_new ((AdwPreferencesDialog*) self);
				g_object_ref_sink (_tmp7_);
				_tmp8_ = _tmp7_;
				gee_abstract_map_set ((GeeAbstractMap*) _tmp6_, page, (DialogsPreferencesPagesBasePage*) _tmp8_);
				_g_object_unref0 (_tmp8_);
				break;
			}
		}
	} else if (_tmp5_ == ((0 != _tmp4_label1) ? _tmp4_label1 : (_tmp4_label1 = g_quark_from_static_string ("home-view")))) {
		switch (0) {
			default:
			{
				GeeHashMap* _tmp9_;
				DialogsPreferencesPagesHomeView* _tmp10_;
				DialogsPreferencesPagesHomeView* _tmp11_;
				_tmp9_ = self->priv->page_map;
				_tmp10_ = dialogs_preferences_pages_home_view_new ((AdwPreferencesDialog*) self);
				g_object_ref_sink (_tmp10_);
				_tmp11_ = _tmp10_;
				gee_abstract_map_set ((GeeAbstractMap*) _tmp9_, page, (DialogsPreferencesPagesBasePage*) _tmp11_);
				_g_object_unref0 (_tmp11_);
				break;
			}
		}
	} else if (_tmp5_ == ((0 != _tmp4_label2) ? _tmp4_label2 : (_tmp4_label2 = g_quark_from_static_string ("appearance")))) {
		switch (0) {
			default:
			{
				GeeHashMap* _tmp12_;
				DialogsPreferencesPagesAppearance* _tmp13_;
				DialogsPreferencesPagesAppearance* _tmp14_;
				_tmp12_ = self->priv->page_map;
				_tmp13_ = dialogs_preferences_pages_appearance_new ((AdwPreferencesDialog*) self);
				g_object_ref_sink (_tmp13_);
				_tmp14_ = _tmp13_;
				gee_abstract_map_set ((GeeAbstractMap*) _tmp12_, page, (DialogsPreferencesPagesBasePage*) _tmp14_);
				_g_object_unref0 (_tmp14_);
				break;
			}
		}
	} else if (_tmp5_ == ((0 != _tmp4_label3) ? _tmp4_label3 : (_tmp4_label3 = g_quark_from_static_string ("backups-page")))) {
		switch (0) {
			default:
			{
				GeeHashMap* _tmp15_;
				DialogsPreferencesPagesBackup* _tmp16_;
				DialogsPreferencesPagesBackup* _tmp17_;
				_tmp15_ = self->priv->page_map;
				_tmp16_ = dialogs_preferences_pages_backup_new ((AdwPreferencesDialog*) self);
				g_object_ref_sink (_tmp16_);
				_tmp17_ = _tmp16_;
				gee_abstract_map_set ((GeeAbstractMap*) _tmp15_, page, (DialogsPreferencesPagesBasePage*) _tmp17_);
				_g_object_unref0 (_tmp17_);
				break;
			}
		}
	} else if (_tmp5_ == ((0 != _tmp4_label4) ? _tmp4_label4 : (_tmp4_label4 = g_quark_from_static_string ("sidebar-page")))) {
		switch (0) {
			default:
			{
				GeeHashMap* _tmp18_;
				DialogsPreferencesPagesSidebar* _tmp19_;
				DialogsPreferencesPagesSidebar* _tmp20_;
				_tmp18_ = self->priv->page_map;
				_tmp19_ = dialogs_preferences_pages_sidebar_new ((AdwPreferencesDialog*) self);
				g_object_ref_sink (_tmp19_);
				_tmp20_ = _tmp19_;
				gee_abstract_map_set ((GeeAbstractMap*) _tmp18_, page, (DialogsPreferencesPagesBasePage*) _tmp20_);
				_g_object_unref0 (_tmp20_);
				break;
			}
		}
	} else if (_tmp5_ == ((0 != _tmp4_label5) ? _tmp4_label5 : (_tmp4_label5 = g_quark_from_static_string ("general-page")))) {
		switch (0) {
			default:
			{
				GeeHashMap* _tmp21_;
				DialogsPreferencesPagesGeneral* _tmp22_;
				DialogsPreferencesPagesGeneral* _tmp23_;
				_tmp21_ = self->priv->page_map;
				_tmp22_ = dialogs_preferences_pages_general_new ((AdwPreferencesDialog*) self);
				g_object_ref_sink (_tmp22_);
				_tmp23_ = _tmp22_;
				gee_abstract_map_set ((GeeAbstractMap*) _tmp21_, page, (DialogsPreferencesPagesBasePage*) _tmp23_);
				_g_object_unref0 (_tmp23_);
				break;
			}
		}
	} else if (_tmp5_ == ((0 != _tmp4_label6) ? _tmp4_label6 : (_tmp4_label6 = g_quark_from_static_string ("task-setting")))) {
		switch (0) {
			default:
			{
				GeeHashMap* _tmp24_;
				DialogsPreferencesPagesTaskSetting* _tmp25_;
				DialogsPreferencesPagesTaskSetting* _tmp26_;
				_tmp24_ = self->priv->page_map;
				_tmp25_ = dialogs_preferences_pages_task_setting_new ((AdwPreferencesDialog*) self);
				g_object_ref_sink (_tmp25_);
				_tmp26_ = _tmp25_;
				gee_abstract_map_set ((GeeAbstractMap*) _tmp24_, page, (DialogsPreferencesPagesBasePage*) _tmp26_);
				_g_object_unref0 (_tmp26_);
				break;
			}
		}
	} else if (_tmp5_ == ((0 != _tmp4_label7) ? _tmp4_label7 : (_tmp4_label7 = g_quark_from_static_string ("quick-add")))) {
		switch (0) {
			default:
			{
				GeeHashMap* _tmp27_;
				DialogsPreferencesPagesQuickAdd* _tmp28_;
				DialogsPreferencesPagesQuickAdd* _tmp29_;
				_tmp27_ = self->priv->page_map;
				_tmp28_ = dialogs_preferences_pages_quick_add_new ((AdwPreferencesDialog*) self);
				g_object_ref_sink (_tmp28_);
				_tmp29_ = _tmp28_;
				gee_abstract_map_set ((GeeAbstractMap*) _tmp27_, page, (DialogsPreferencesPagesBasePage*) _tmp29_);
				_g_object_unref0 (_tmp29_);
				break;
			}
		}
	} else if (_tmp5_ == ((0 != _tmp4_label8) ? _tmp4_label8 : (_tmp4_label8 = g_quark_from_static_string ("donate")))) {
		switch (0) {
			default:
			{
				GeeHashMap* _tmp30_;
				DialogsPreferencesPagesDonate* _tmp31_;
				DialogsPreferencesPagesDonate* _tmp32_;
				_tmp30_ = self->priv->page_map;
				_tmp31_ = dialogs_preferences_pages_donate_new ((AdwPreferencesDialog*) self);
				g_object_ref_sink (_tmp31_);
				_tmp32_ = _tmp31_;
				gee_abstract_map_set ((GeeAbstractMap*) _tmp30_, page, (DialogsPreferencesPagesBasePage*) _tmp32_);
				_g_object_unref0 (_tmp32_);
				break;
			}
		}
	} else {
		switch (0) {
			default:
			{
				g_warning ("PreferencesWindow.vala:379: The page %s does not exist\n", page);
				result = NULL;
				return result;
			}
		}
	}
	_tmp33_ = self->priv->page_map;
	_tmp34_ = gee_abstract_map_get ((GeeAbstractMap*) _tmp33_, page);
	result = (AdwNavigationPage*) ((DialogsPreferencesPagesBasePage*) _tmp34_);
	return result;
}

void
dialogs_preferences_preferences_window_show_page (DialogsPreferencesPreferencesWindow* self,
                                                  const gchar* page_key)
{
	AdwNavigationPage* page = NULL;
	AdwNavigationPage* _tmp0_;
	AdwNavigationPage* _tmp1_;
	g_return_if_fail (self != NULL);
	g_return_if_fail (page_key != NULL);
	_tmp0_ = dialogs_preferences_preferences_window_build_page (self, page_key);
	page = _tmp0_;
	_tmp1_ = page;
	if (_tmp1_ != NULL) {
		AdwNavigationPage* _tmp2_;
		_tmp2_ = page;
		adw_preferences_dialog_push_subpage ((AdwPreferencesDialog*) self, _tmp2_);
	}
	_g_object_unref0 (page);
}

void
dialogs_preferences_preferences_window_clean_up (DialogsPreferencesPreferencesWindow* self)
{
	GeeHashMap* _tmp15_;
	GtkShortcutController* _tmp16_;
	GeeHashMap* _tmp28_;
	g_return_if_fail (self != NULL);
	{
		GeeIterator* _entry_it = NULL;
		GeeHashMap* _tmp0_;
		GeeSet* _tmp1_;
		GeeSet* _tmp2_;
		GeeSet* _tmp3_;
		GeeIterator* _tmp4_;
		GeeIterator* _tmp5_;
		_tmp0_ = self->signal_map;
		_tmp1_ = gee_abstract_map_get_entries ((GeeAbstractMap*) _tmp0_);
		_tmp2_ = _tmp1_;
		_tmp3_ = _tmp2_;
		_tmp4_ = gee_iterable_iterator ((GeeIterable*) _tmp3_);
		_tmp5_ = _tmp4_;
		_g_object_unref0 (_tmp3_);
		_entry_it = _tmp5_;
		while (TRUE) {
			GeeIterator* _tmp6_;
			GeeMapEntry* entry = NULL;
			GeeIterator* _tmp7_;
			gpointer _tmp8_;
			GeeMapEntry* _tmp9_;
			gconstpointer _tmp10_;
			gconstpointer _tmp11_;
			GeeMapEntry* _tmp12_;
			gconstpointer _tmp13_;
			gconstpointer _tmp14_;
			_tmp6_ = _entry_it;
			if (!gee_iterator_next (_tmp6_)) {
				break;
			}
			_tmp7_ = _entry_it;
			_tmp8_ = gee_iterator_get (_tmp7_);
			entry = (GeeMapEntry*) _tmp8_;
			_tmp9_ = entry;
			_tmp10_ = gee_map_entry_get_value (_tmp9_);
			_tmp11_ = _tmp10_;
			_tmp12_ = entry;
			_tmp13_ = gee_map_entry_get_key (_tmp12_);
			_tmp14_ = _tmp13_;
			g_signal_handler_disconnect ((GObject*) _tmp11_, (gulong) ((guintptr) _tmp14_));
			_g_object_unref0 (entry);
		}
		_g_object_unref0 (_entry_it);
	}
	_tmp15_ = self->signal_map;
	gee_abstract_map_clear ((GeeAbstractMap*) _tmp15_);
	_tmp16_ = self->priv->shortcut_controller;
	if (_tmp16_ != NULL) {
		GtkShortcutController* _tmp17_;
		_tmp17_ = self->priv->shortcut_controller;
		G_TYPE_INSTANCE_GET_INTERFACE ((GtkShortcutManager*) self, gtk_shortcut_manager_get_type (), GtkShortcutManagerInterface)->remove_controller ((GtkShortcutManager*) self, _tmp17_);
		_g_object_unref0 (self->priv->shortcut_controller);
		self->priv->shortcut_controller = NULL;
	}
	{
		GeeIterator* _page_it = NULL;
		GeeHashMap* _tmp18_;
		GeeCollection* _tmp19_;
		GeeCollection* _tmp20_;
		GeeCollection* _tmp21_;
		GeeIterator* _tmp22_;
		GeeIterator* _tmp23_;
		_tmp18_ = self->priv->page_map;
		_tmp19_ = gee_abstract_map_get_values ((GeeAbstractMap*) _tmp18_);
		_tmp20_ = _tmp19_;
		_tmp21_ = _tmp20_;
		_tmp22_ = gee_iterable_iterator ((GeeIterable*) _tmp21_);
		_tmp23_ = _tmp22_;
		_g_object_unref0 (_tmp21_);
		_page_it = _tmp23_;
		while (TRUE) {
			GeeIterator* _tmp24_;
			DialogsPreferencesPagesBasePage* page = NULL;
			GeeIterator* _tmp25_;
			gpointer _tmp26_;
			DialogsPreferencesPagesBasePage* _tmp27_;
			_tmp24_ = _page_it;
			if (!gee_iterator_next (_tmp24_)) {
				break;
			}
			_tmp25_ = _page_it;
			_tmp26_ = gee_iterator_get (_tmp25_);
			page = (DialogsPreferencesPagesBasePage*) _tmp26_;
			_tmp27_ = page;
			dialogs_preferences_pages_base_page_clean_up (_tmp27_);
			_g_object_unref0 (page);
		}
		_g_object_unref0 (_page_it);
	}
	_tmp28_ = self->priv->page_map;
	gee_abstract_map_clear ((GeeAbstractMap*) _tmp28_);
}

static gpointer
_g_object_ref0 (gpointer self)
{
	return self ? g_object_ref (self) : NULL;
}

static Block94Data*
block94_data_ref (Block94Data* _data94_)
{
	g_atomic_int_inc (&_data94_->_ref_count_);
	return _data94_;
}

static void
block94_data_unref (void * _userdata_)
{
	Block94Data* _data94_;
	_data94_ = (Block94Data*) _userdata_;
	if (g_atomic_int_dec_and_test (&_data94_->_ref_count_)) {
		DialogsPreferencesPreferencesWindow* self;
		self = _data94_->self;
		_g_object_unref0 (_data94_->translation_row);
		_g_object_unref0 (self);
		g_slice_free (Block94Data, _data94_);
	}
}

static gboolean
__lambda431_ (Block94Data* _data94_)
{
	DialogsPreferencesPreferencesWindow* self;
	gboolean result;
	self = _data94_->self;
	widgets_translation_row_trigger_animation (_data94_->translation_row);
	result = FALSE;
	return result;
}

static gboolean
___lambda431__gsource_func (gpointer self)
{
	gboolean result;
	result = __lambda431_ (self);
	return result;
}

static void
__lambda430_ (Block94Data* _data94_)
{
	DialogsPreferencesPreferencesWindow* self;
	self = _data94_->self;
	g_timeout_add_full (G_PRIORITY_DEFAULT, (guint) 1500, ___lambda431__gsource_func, block94_data_ref (_data94_), block94_data_unref);
}

static void
___lambda430__gtk_widget_map (GtkWidget* _sender,
                              gpointer self)
{
	__lambda430_ (self);
}

static void
dialogs_preferences_preferences_window_setup_visibility_detection (DialogsPreferencesPreferencesWindow* self,
                                                                   WidgetsTranslationRow* translation_row)
{
	Block94Data* _data94_;
	WidgetsTranslationRow* _tmp0_;
	g_return_if_fail (self != NULL);
	g_return_if_fail (translation_row != NULL);
	_data94_ = g_slice_new0 (Block94Data);
	_data94_->_ref_count_ = 1;
	_data94_->self = g_object_ref (self);
	_tmp0_ = _g_object_ref0 (translation_row);
	_g_object_unref0 (_data94_->translation_row);
	_data94_->translation_row = _tmp0_;
	widgets_translation_row_load_translation_data (_data94_->translation_row, NULL, NULL);
	g_signal_connect_data ((GtkWidget*) _data94_->translation_row, "map", (GCallback) ___lambda430__gtk_widget_map, block94_data_ref (_data94_), (GClosureNotify) block94_data_unref, 0);
	block94_data_unref (_data94_);
	_data94_ = NULL;
}

static void
_dialogs_preferences_preferences_window___lambda432_ (DialogsPreferencesPreferencesWindow* self)
{
	AdwNavigationPage* _tmp0_;
	AdwNavigationPage* _tmp1_;
	_tmp0_ = dialogs_preferences_preferences_window_build_page (self, "accounts");
	_tmp1_ = _tmp0_;
	adw_preferences_dialog_push_subpage ((AdwPreferencesDialog*) self, _tmp1_);
	_g_object_unref0 (_tmp1_);
}

static void
__dialogs_preferences_preferences_window___lambda432__adw_action_row_activated (AdwActionRow* _sender,
                                                                                gpointer self)
{
	_dialogs_preferences_preferences_window___lambda432_ ((DialogsPreferencesPreferencesWindow*) self);
}

static void
_dialogs_preferences_preferences_window___lambda433_ (DialogsPreferencesPreferencesWindow* self)
{
	AdwNavigationPage* _tmp0_;
	AdwNavigationPage* _tmp1_;
	_tmp0_ = dialogs_preferences_preferences_window_build_page (self, "home-view");
	_tmp1_ = _tmp0_;
	adw_preferences_dialog_push_subpage ((AdwPreferencesDialog*) self, _tmp1_);
	_g_object_unref0 (_tmp1_);
}

static void
__dialogs_preferences_preferences_window___lambda433__adw_action_row_activated (AdwActionRow* _sender,
                                                                                gpointer self)
{
	_dialogs_preferences_preferences_window___lambda433_ ((DialogsPreferencesPreferencesWindow*) self);
}

static void
_dialogs_preferences_preferences_window___lambda434_ (DialogsPreferencesPreferencesWindow* self)
{
	AdwNavigationPage* _tmp0_;
	AdwNavigationPage* _tmp1_;
	_tmp0_ = dialogs_preferences_preferences_window_build_page (self, "general-page");
	_tmp1_ = _tmp0_;
	adw_preferences_dialog_push_subpage ((AdwPreferencesDialog*) self, _tmp1_);
	_g_object_unref0 (_tmp1_);
}

static void
__dialogs_preferences_preferences_window___lambda434__adw_action_row_activated (AdwActionRow* _sender,
                                                                                gpointer self)
{
	_dialogs_preferences_preferences_window___lambda434_ ((DialogsPreferencesPreferencesWindow*) self);
}

static void
_dialogs_preferences_preferences_window___lambda435_ (DialogsPreferencesPreferencesWindow* self)
{
	AdwNavigationPage* _tmp0_;
	AdwNavigationPage* _tmp1_;
	_tmp0_ = dialogs_preferences_preferences_window_build_page (self, "task-setting");
	_tmp1_ = _tmp0_;
	adw_preferences_dialog_push_subpage ((AdwPreferencesDialog*) self, _tmp1_);
	_g_object_unref0 (_tmp1_);
}

static void
__dialogs_preferences_preferences_window___lambda435__adw_action_row_activated (AdwActionRow* _sender,
                                                                                gpointer self)
{
	_dialogs_preferences_preferences_window___lambda435_ ((DialogsPreferencesPreferencesWindow*) self);
}

static void
_dialogs_preferences_preferences_window___lambda436_ (DialogsPreferencesPreferencesWindow* self)
{
	AdwNavigationPage* _tmp0_;
	AdwNavigationPage* _tmp1_;
	_tmp0_ = dialogs_preferences_preferences_window_build_page (self, "sidebar-page");
	_tmp1_ = _tmp0_;
	adw_preferences_dialog_push_subpage ((AdwPreferencesDialog*) self, _tmp1_);
	_g_object_unref0 (_tmp1_);
}

static void
__dialogs_preferences_preferences_window___lambda436__adw_action_row_activated (AdwActionRow* _sender,
                                                                                gpointer self)
{
	_dialogs_preferences_preferences_window___lambda436_ ((DialogsPreferencesPreferencesWindow*) self);
}

static void
_dialogs_preferences_preferences_window___lambda437_ (DialogsPreferencesPreferencesWindow* self)
{
	AdwNavigationPage* _tmp0_;
	AdwNavigationPage* _tmp1_;
	_tmp0_ = dialogs_preferences_preferences_window_build_page (self, "appearance");
	_tmp1_ = _tmp0_;
	adw_preferences_dialog_push_subpage ((AdwPreferencesDialog*) self, _tmp1_);
	_g_object_unref0 (_tmp1_);
}

static void
__dialogs_preferences_preferences_window___lambda437__adw_action_row_activated (AdwActionRow* _sender,
                                                                                gpointer self)
{
	_dialogs_preferences_preferences_window___lambda437_ ((DialogsPreferencesPreferencesWindow*) self);
}

static void
_dialogs_preferences_preferences_window___lambda438_ (DialogsPreferencesPreferencesWindow* self)
{
	AdwNavigationPage* _tmp0_;
	AdwNavigationPage* _tmp1_;
	_tmp0_ = dialogs_preferences_preferences_window_build_page (self, "quick-add");
	_tmp1_ = _tmp0_;
	adw_preferences_dialog_push_subpage ((AdwPreferencesDialog*) self, _tmp1_);
	_g_object_unref0 (_tmp1_);
}

static void
__dialogs_preferences_preferences_window___lambda438__adw_action_row_activated (AdwActionRow* _sender,
                                                                                gpointer self)
{
	_dialogs_preferences_preferences_window___lambda438_ ((DialogsPreferencesPreferencesWindow*) self);
}

static void
_dialogs_preferences_preferences_window___lambda439_ (DialogsPreferencesPreferencesWindow* self)
{
	AdwNavigationPage* _tmp0_;
	AdwNavigationPage* _tmp1_;
	_tmp0_ = dialogs_preferences_preferences_window_build_page (self, "donate");
	_tmp1_ = _tmp0_;
	adw_preferences_dialog_push_subpage ((AdwPreferencesDialog*) self, _tmp1_);
	_g_object_unref0 (_tmp1_);
}

static void
__dialogs_preferences_preferences_window___lambda439__adw_action_row_activated (AdwActionRow* _sender,
                                                                                gpointer self)
{
	_dialogs_preferences_preferences_window___lambda439_ ((DialogsPreferencesPreferencesWindow*) self);
}

static void
_dialogs_preferences_preferences_window___lambda440_ (DialogsPreferencesPreferencesWindow* self)
{
	GError* _inner_error0_ = NULL;
	{
		g_app_info_launch_default_for_uri (CONSTANTS_ISSUE_URL, NULL, &_inner_error0_);
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
			goto __catch0_g_error;
		}
	}
	goto __finally0;
	__catch0_g_error:
	{
		GError* e = NULL;
		GError* _tmp0_;
		const gchar* _tmp1_;
		e = _inner_error0_;
		_inner_error0_ = NULL;
		_tmp0_ = e;
		_tmp1_ = _tmp0_->message;
		g_warning ("PreferencesWindow.vala:176: %s\n", _tmp1_);
		_g_error_free0 (e);
	}
	__finally0:
	if (G_UNLIKELY (_inner_error0_ != NULL)) {
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error0_->message, g_quark_to_string (_inner_error0_->domain), _inner_error0_->code);
		g_clear_error (&_inner_error0_);
		return;
	}
}

static void
__dialogs_preferences_preferences_window___lambda440__adw_action_row_activated (AdwActionRow* _sender,
                                                                                gpointer self)
{
	_dialogs_preferences_preferences_window___lambda440_ ((DialogsPreferencesPreferencesWindow*) self);
}

static void
_dialogs_preferences_preferences_window___lambda441_ (DialogsPreferencesPreferencesWindow* self)
{
	GError* _inner_error0_ = NULL;
	{
		g_app_info_launch_default_for_uri (CONSTANTS_WEBLATE_URL, NULL, &_inner_error0_);
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
			goto __catch0_g_error;
		}
	}
	goto __finally0;
	__catch0_g_error:
	{
		GError* e = NULL;
		GError* _tmp0_;
		const gchar* _tmp1_;
		e = _inner_error0_;
		_inner_error0_ = NULL;
		_tmp0_ = e;
		_tmp1_ = _tmp0_->message;
		g_warning ("PreferencesWindow.vala:191: %s\n", _tmp1_);
		_g_error_free0 (e);
	}
	__finally0:
	if (G_UNLIKELY (_inner_error0_ != NULL)) {
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error0_->message, g_quark_to_string (_inner_error0_->domain), _inner_error0_->code);
		g_clear_error (&_inner_error0_);
		return;
	}
}

static void
__dialogs_preferences_preferences_window___lambda441__gtk_gesture_click_pressed (GtkGestureClick* _sender,
                                                                                 gint n_press,
                                                                                 gdouble x,
                                                                                 gdouble y,
                                                                                 gpointer self)
{
	_dialogs_preferences_preferences_window___lambda441_ ((DialogsPreferencesPreferencesWindow*) self);
}

static void
_dialogs_preferences_preferences_window___lambda442_ (DialogsPreferencesPreferencesWindow* self)
{
	gchar* uri = NULL;
	gchar* _tmp0_;
	GError* _inner_error0_ = NULL;
	_tmp0_ = g_strdup_printf ("mailto:%s", CONSTANTS_CONTACT_US);
	uri = _tmp0_;
	{
		const gchar* _tmp1_;
		_tmp1_ = uri;
		g_app_info_launch_default_for_uri (_tmp1_, NULL, &_inner_error0_);
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
			goto __catch0_g_error;
		}
	}
	goto __finally0;
	__catch0_g_error:
	{
		GError* e = NULL;
		GError* _tmp2_;
		const gchar* _tmp3_;
		e = _inner_error0_;
		_inner_error0_ = NULL;
		_tmp2_ = e;
		_tmp3_ = _tmp2_->message;
		g_warning ("PreferencesWindow.vala:221: %s\n", _tmp3_);
		_g_error_free0 (e);
	}
	__finally0:
	if (G_UNLIKELY (_inner_error0_ != NULL)) {
		_g_free0 (uri);
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error0_->message, g_quark_to_string (_inner_error0_->domain), _inner_error0_->code);
		g_clear_error (&_inner_error0_);
		return;
	}
	_g_free0 (uri);
}

static void
__dialogs_preferences_preferences_window___lambda442__adw_action_row_activated (AdwActionRow* _sender,
                                                                                gpointer self)
{
	_dialogs_preferences_preferences_window___lambda442_ ((DialogsPreferencesPreferencesWindow*) self);
}

static void
_dialogs_preferences_preferences_window___lambda443_ (DialogsPreferencesPreferencesWindow* self)
{
	GError* _inner_error0_ = NULL;
	{
		g_app_info_launch_default_for_uri (CONSTANTS_TWITTER_URL, NULL, &_inner_error0_);
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
			goto __catch0_g_error;
		}
	}
	goto __finally0;
	__catch0_g_error:
	{
		GError* e = NULL;
		GError* _tmp0_;
		const gchar* _tmp1_;
		e = _inner_error0_;
		_inner_error0_ = NULL;
		_tmp0_ = e;
		_tmp1_ = _tmp0_->message;
		g_warning ("PreferencesWindow.vala:236: %s\n", _tmp1_);
		_g_error_free0 (e);
	}
	__finally0:
	if (G_UNLIKELY (_inner_error0_ != NULL)) {
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error0_->message, g_quark_to_string (_inner_error0_->domain), _inner_error0_->code);
		g_clear_error (&_inner_error0_);
		return;
	}
}

static void
__dialogs_preferences_preferences_window___lambda443__adw_action_row_activated (AdwActionRow* _sender,
                                                                                gpointer self)
{
	_dialogs_preferences_preferences_window___lambda443_ ((DialogsPreferencesPreferencesWindow*) self);
}

static void
_dialogs_preferences_preferences_window___lambda444_ (DialogsPreferencesPreferencesWindow* self)
{
	GError* _inner_error0_ = NULL;
	{
		g_app_info_launch_default_for_uri (CONSTANTS_DISCORD_URL, NULL, &_inner_error0_);
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
			goto __catch0_g_error;
		}
	}
	goto __finally0;
	__catch0_g_error:
	{
		GError* e = NULL;
		GError* _tmp0_;
		const gchar* _tmp1_;
		e = _inner_error0_;
		_inner_error0_ = NULL;
		_tmp0_ = e;
		_tmp1_ = _tmp0_->message;
		g_warning ("PreferencesWindow.vala:251: %s\n", _tmp1_);
		_g_error_free0 (e);
	}
	__finally0:
	if (G_UNLIKELY (_inner_error0_ != NULL)) {
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error0_->message, g_quark_to_string (_inner_error0_->domain), _inner_error0_->code);
		g_clear_error (&_inner_error0_);
		return;
	}
}

static void
__dialogs_preferences_preferences_window___lambda444__adw_action_row_activated (AdwActionRow* _sender,
                                                                                gpointer self)
{
	_dialogs_preferences_preferences_window___lambda444_ ((DialogsPreferencesPreferencesWindow*) self);
}

static void
_dialogs_preferences_preferences_window___lambda445_ (DialogsPreferencesPreferencesWindow* self)
{
	GError* _inner_error0_ = NULL;
	{
		g_app_info_launch_default_for_uri (CONSTANTS_MASTODON_URL, NULL, &_inner_error0_);
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
			goto __catch0_g_error;
		}
	}
	goto __finally0;
	__catch0_g_error:
	{
		GError* e = NULL;
		GError* _tmp0_;
		const gchar* _tmp1_;
		e = _inner_error0_;
		_inner_error0_ = NULL;
		_tmp0_ = e;
		_tmp1_ = _tmp0_->message;
		g_warning ("PreferencesWindow.vala:266: %s\n", _tmp1_);
		_g_error_free0 (e);
	}
	__finally0:
	if (G_UNLIKELY (_inner_error0_ != NULL)) {
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error0_->message, g_quark_to_string (_inner_error0_->domain), _inner_error0_->code);
		g_clear_error (&_inner_error0_);
		return;
	}
}

static void
__dialogs_preferences_preferences_window___lambda445__adw_action_row_activated (AdwActionRow* _sender,
                                                                                gpointer self)
{
	_dialogs_preferences_preferences_window___lambda445_ ((DialogsPreferencesPreferencesWindow*) self);
}

static void
_dialogs_preferences_preferences_window___lambda446_ (DialogsPreferencesPreferencesWindow* self)
{
	Util* _tmp0_;
	Util* _tmp1_;
	Util* _tmp2_;
	Util* _tmp3_;
	AdwToast* _tmp4_;
	_tmp0_ = util_get_default ();
	_tmp1_ = _tmp0_;
	util_create_tutorial_project (_tmp1_);
	_g_object_unref0 (_tmp1_);
	_tmp2_ = util_get_default ();
	_tmp3_ = _tmp2_;
	_tmp4_ = util_create_toast (_tmp3_, _ ("A tutorial project has been created"), (guint) 2, ADW_TOAST_PRIORITY_NORMAL);
	adw_preferences_dialog_add_toast ((AdwPreferencesDialog*) self, _tmp4_);
	_g_object_unref0 (_tmp3_);
}

static void
__dialogs_preferences_preferences_window___lambda446__adw_action_row_activated (AdwActionRow* _sender,
                                                                                gpointer self)
{
	_dialogs_preferences_preferences_window___lambda446_ ((DialogsPreferencesPreferencesWindow*) self);
}

static void
_dialogs_preferences_preferences_window___lambda447_ (DialogsPreferencesPreferencesWindow* self)
{
	AdwNavigationPage* _tmp0_;
	AdwNavigationPage* _tmp1_;
	_tmp0_ = dialogs_preferences_preferences_window_build_page (self, "backups-page");
	_tmp1_ = _tmp0_;
	adw_preferences_dialog_push_subpage ((AdwPreferencesDialog*) self, _tmp1_);
	_g_object_unref0 (_tmp1_);
}

static void
__dialogs_preferences_preferences_window___lambda447__adw_action_row_activated (AdwActionRow* _sender,
                                                                                gpointer self)
{
	_dialogs_preferences_preferences_window___lambda447_ ((DialogsPreferencesPreferencesWindow*) self);
}

static void
_dialogs_preferences_preferences_window___lambda448_ (DialogsPreferencesPreferencesWindow* self)
{
	GError* _inner_error0_ = NULL;
	{
		g_app_info_launch_default_for_uri (CONSTANTS_PRIVACY_POLICY_URL, NULL, &_inner_error0_);
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
			goto __catch0_g_error;
		}
	}
	goto __finally0;
	__catch0_g_error:
	{
		GError* e = NULL;
		GError* _tmp0_;
		const gchar* _tmp1_;
		e = _inner_error0_;
		_inner_error0_ = NULL;
		_tmp0_ = e;
		_tmp1_ = _tmp0_->message;
		g_warning ("PreferencesWindow.vala:311: %s\n", _tmp1_);
		_g_error_free0 (e);
	}
	__finally0:
	if (G_UNLIKELY (_inner_error0_ != NULL)) {
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error0_->message, g_quark_to_string (_inner_error0_->domain), _inner_error0_->code);
		g_clear_error (&_inner_error0_);
		return;
	}
}

static void
__dialogs_preferences_preferences_window___lambda448__adw_action_row_activated (AdwActionRow* _sender,
                                                                                gpointer self)
{
	_dialogs_preferences_preferences_window___lambda448_ ((DialogsPreferencesPreferencesWindow*) self);
}

static void
_dialogs_preferences_preferences_window___lambda449_ (DialogsPreferencesPreferencesWindow* self)
{
	Util* _tmp0_;
	Util* _tmp1_;
	Planify* _tmp2_;
	Planify* _tmp3_;
	MainWindow* _tmp4_;
	_tmp0_ = util_get_default ();
	_tmp1_ = _tmp0_;
	_tmp2_ = planify_get_instance ();
	_tmp3_ = _tmp2_;
	_tmp4_ = _tmp3_->main_window;
	util_clear_database (_tmp1_, _ ("Delete All Data?"), _ ("Deletes all your lists, tasks, and reminders irreversibly"), (GtkWindow*) _tmp4_);
	_g_object_unref0 (_tmp1_);
}

static void
__dialogs_preferences_preferences_window___lambda449__adw_action_row_activated (AdwActionRow* _sender,
                                                                                gpointer self)
{
	_dialogs_preferences_preferences_window___lambda449_ ((DialogsPreferencesPreferencesWindow*) self);
}

static gboolean
_dialogs_preferences_preferences_window___lambda450_ (DialogsPreferencesPreferencesWindow* self,
                                                      GtkWidget* widget,
                                                      GVariant* args)
{
	gboolean result;
	g_return_val_if_fail (widget != NULL, FALSE);
	adw_dialog_close ((AdwDialog*) self);
	result = TRUE;
	return result;
}

static gboolean
__dialogs_preferences_preferences_window___lambda450__gtk_shortcut_func (GtkWidget* widget,
                                                                         GVariant* args,
                                                                         gpointer self)
{
	gboolean result;
	result = _dialogs_preferences_preferences_window___lambda450_ ((DialogsPreferencesPreferencesWindow*) self, widget, args);
	return result;
}

static void
_dialogs_preferences_preferences_window___lambda451_ (DialogsPreferencesPreferencesWindow* self)
{
	ServicesEventBus* _tmp0_;
	ServicesEventBus* _tmp1_;
	dialogs_preferences_preferences_window_clean_up (self);
	_tmp0_ = services_event_bus_get_default ();
	_tmp1_ = _tmp0_;
	g_signal_emit_by_name (_tmp1_, "connect-typing-accel");
	_g_object_unref0 (_tmp1_);
}

static void
__dialogs_preferences_preferences_window___lambda451__adw_dialog_closed (AdwDialog* _sender,
                                                                         gpointer self)
{
	_dialogs_preferences_preferences_window___lambda451_ ((DialogsPreferencesPreferencesWindow*) self);
}

static GObject *
dialogs_preferences_preferences_window_constructor (GType type,
                                                    guint n_construct_properties,
                                                    GObjectConstructParam * construct_properties)
{
	GObject * obj;
	GObjectClass * parent_class;
	DialogsPreferencesPreferencesWindow * self;
	AdwPreferencesPage* page = NULL;
	AdwPreferencesPage* _tmp0_;
	AdwPreferencesPage* _tmp1_;
	AdwPreferencesPage* _tmp2_;
	AdwPreferencesPage* _tmp3_;
	AdwActionRow* accounts_row = NULL;
	AdwActionRow* _tmp4_;
	AdwActionRow* _tmp5_;
	AdwActionRow* _tmp6_;
	GtkWidget* _tmp7_;
	GtkWidget* _tmp8_;
	AdwActionRow* _tmp9_;
	GtkWidget* _tmp10_;
	GtkWidget* _tmp11_;
	AdwActionRow* _tmp12_;
	AdwActionRow* _tmp13_;
	GeeHashMap* _tmp14_;
	AdwActionRow* _tmp15_;
	gulong _tmp16_;
	AdwActionRow* _tmp17_;
	AdwPreferencesGroup* accounts_group = NULL;
	AdwPreferencesGroup* _tmp18_;
	AdwPreferencesGroup* _tmp19_;
	AdwActionRow* _tmp20_;
	AdwPreferencesPage* _tmp21_;
	AdwPreferencesGroup* _tmp22_;
	AdwActionRow* home_page_row = NULL;
	gchar* _tmp23_;
	gchar* _tmp24_;
	AdwActionRow* _tmp25_ = NULL;
	AdwActionRow* _tmp26_;
	GtkWidget* _tmp27_;
	GtkWidget* _tmp28_;
	AdwActionRow* _tmp29_;
	GtkWidget* _tmp30_;
	GtkWidget* _tmp31_;
	GeeHashMap* _tmp32_;
	AdwActionRow* _tmp33_;
	gulong _tmp34_;
	AdwActionRow* _tmp35_;
	AdwActionRow* general_row = NULL;
	AdwActionRow* _tmp36_;
	AdwActionRow* _tmp37_;
	AdwActionRow* _tmp38_;
	GtkWidget* _tmp39_;
	GtkWidget* _tmp40_;
	AdwActionRow* _tmp41_;
	GtkWidget* _tmp42_;
	GtkWidget* _tmp43_;
	AdwActionRow* _tmp44_;
	AdwActionRow* _tmp45_;
	GeeHashMap* _tmp46_;
	AdwActionRow* _tmp47_;
	gulong _tmp48_;
	AdwActionRow* _tmp49_;
	AdwActionRow* task_setting_row = NULL;
	AdwActionRow* _tmp50_;
	AdwActionRow* _tmp51_;
	AdwActionRow* _tmp52_;
	GtkWidget* _tmp53_;
	GtkWidget* _tmp54_;
	AdwActionRow* _tmp55_;
	GtkWidget* _tmp56_;
	GtkWidget* _tmp57_;
	AdwActionRow* _tmp58_;
	GeeHashMap* _tmp59_;
	AdwActionRow* _tmp60_;
	gulong _tmp61_;
	AdwActionRow* _tmp62_;
	AdwActionRow* sidebar_row = NULL;
	AdwActionRow* _tmp63_;
	AdwActionRow* _tmp64_;
	AdwActionRow* _tmp65_;
	GtkWidget* _tmp66_;
	GtkWidget* _tmp67_;
	AdwActionRow* _tmp68_;
	GtkWidget* _tmp69_;
	GtkWidget* _tmp70_;
	AdwActionRow* _tmp71_;
	AdwActionRow* _tmp72_;
	GeeHashMap* _tmp73_;
	AdwActionRow* _tmp74_;
	gulong _tmp75_;
	AdwActionRow* _tmp76_;
	AdwActionRow* appearance_row = NULL;
	AdwActionRow* _tmp77_;
	AdwActionRow* _tmp78_;
	AdwActionRow* _tmp79_;
	GtkWidget* _tmp80_;
	GtkWidget* _tmp81_;
	AdwActionRow* _tmp82_;
	GtkWidget* _tmp83_;
	GtkWidget* _tmp84_;
	AdwActionRow* _tmp85_;
	AdwActionRow* _tmp86_;
	Util* _tmp87_;
	Util* _tmp88_;
	gchar* _tmp89_;
	gchar* _tmp90_;
	GeeHashMap* _tmp91_;
	AdwActionRow* _tmp92_;
	gulong _tmp93_;
	AdwActionRow* _tmp94_;
	AdwActionRow* quick_add_row = NULL;
	AdwActionRow* _tmp95_;
	AdwActionRow* _tmp96_;
	AdwActionRow* _tmp97_;
	GtkWidget* _tmp98_;
	GtkWidget* _tmp99_;
	AdwActionRow* _tmp100_;
	GtkWidget* _tmp101_;
	GtkWidget* _tmp102_;
	AdwActionRow* _tmp103_;
	AdwActionRow* _tmp104_;
	GeeHashMap* _tmp105_;
	AdwActionRow* _tmp106_;
	gulong _tmp107_;
	AdwActionRow* _tmp108_;
	AdwActionRow* backups_row = NULL;
	AdwActionRow* _tmp109_;
	AdwActionRow* _tmp110_;
	AdwActionRow* _tmp111_;
	GtkWidget* _tmp112_;
	GtkWidget* _tmp113_;
	AdwActionRow* _tmp114_;
	GtkWidget* _tmp115_;
	GtkWidget* _tmp116_;
	AdwActionRow* _tmp117_;
	AdwActionRow* _tmp118_;
	AdwActionRow* tutorial_row = NULL;
	AdwActionRow* _tmp119_;
	AdwActionRow* _tmp120_;
	AdwActionRow* _tmp121_;
	GtkWidget* _tmp122_;
	GtkWidget* _tmp123_;
	AdwActionRow* _tmp124_;
	GtkWidget* _tmp125_;
	GtkWidget* _tmp126_;
	AdwActionRow* _tmp127_;
	AdwActionRow* _tmp128_;
	AdwPreferencesGroup* personalization_group = NULL;
	AdwPreferencesGroup* _tmp129_;
	AdwPreferencesGroup* _tmp130_;
	AdwActionRow* _tmp131_;
	AdwPreferencesGroup* _tmp132_;
	AdwActionRow* _tmp133_;
	AdwPreferencesGroup* _tmp134_;
	AdwActionRow* _tmp135_;
	AdwPreferencesGroup* _tmp136_;
	AdwActionRow* _tmp137_;
	AdwPreferencesGroup* _tmp138_;
	AdwActionRow* _tmp139_;
	AdwPreferencesGroup* _tmp140_;
	AdwActionRow* _tmp141_;
	AdwPreferencesGroup* _tmp142_;
	AdwActionRow* _tmp143_;
	AdwPreferencesGroup* _tmp144_;
	AdwActionRow* _tmp145_;
	AdwPreferencesPage* _tmp146_;
	AdwPreferencesGroup* _tmp147_;
	AdwActionRow* supporting_us_row = NULL;
	AdwActionRow* _tmp148_;
	AdwActionRow* _tmp149_;
	AdwActionRow* _tmp150_;
	GtkWidget* _tmp151_;
	GtkWidget* _tmp152_;
	AdwActionRow* _tmp153_;
	GtkWidget* _tmp154_;
	GtkWidget* _tmp155_;
	AdwActionRow* _tmp156_;
	AdwActionRow* _tmp157_;
	GeeHashMap* _tmp158_;
	AdwActionRow* _tmp159_;
	gulong _tmp160_;
	AdwActionRow* _tmp161_;
	AdwActionRow* issue_row = NULL;
	AdwActionRow* _tmp162_;
	AdwActionRow* _tmp163_;
	AdwActionRow* _tmp164_;
	GtkWidget* _tmp165_;
	GtkWidget* _tmp166_;
	AdwActionRow* _tmp167_;
	GtkWidget* _tmp168_;
	GtkWidget* _tmp169_;
	AdwActionRow* _tmp170_;
	AdwActionRow* _tmp171_;
	GeeHashMap* _tmp172_;
	AdwActionRow* _tmp173_;
	gulong _tmp174_;
	AdwActionRow* _tmp175_;
	WidgetsTranslationRow* translation_row = NULL;
	WidgetsTranslationRow* _tmp176_;
	WidgetsTranslationRow* _tmp177_;
	WidgetsTranslationRow* _tmp178_;
	GtkGestureClick* click_gesture = NULL;
	GtkGestureClick* _tmp179_;
	WidgetsTranslationRow* _tmp180_;
	GtkGestureClick* _tmp181_;
	GtkEventController* _tmp182_;
	GeeHashMap* _tmp183_;
	GtkGestureClick* _tmp184_;
	gulong _tmp185_;
	GtkGestureClick* _tmp186_;
	AdwPreferencesGroup* collaboration_group = NULL;
	AdwPreferencesGroup* _tmp187_;
	AdwPreferencesGroup* _tmp188_;
	AdwPreferencesGroup* _tmp189_;
	AdwActionRow* _tmp190_;
	AdwPreferencesGroup* _tmp191_;
	AdwActionRow* _tmp192_;
	AdwPreferencesGroup* _tmp193_;
	WidgetsTranslationRow* _tmp194_;
	AdwPreferencesPage* _tmp195_;
	AdwPreferencesGroup* _tmp196_;
	AdwPreferencesGroup* reach_us_group = NULL;
	AdwPreferencesGroup* _tmp197_;
	AdwPreferencesGroup* _tmp198_;
	AdwActionRow* contact_us_row = NULL;
	AdwActionRow* _tmp199_;
	AdwActionRow* _tmp200_;
	AdwActionRow* _tmp201_;
	GtkWidget* _tmp202_;
	GtkWidget* _tmp203_;
	AdwActionRow* _tmp204_;
	GtkWidget* _tmp205_;
	GtkWidget* _tmp206_;
	AdwActionRow* _tmp207_;
	AdwActionRow* _tmp208_;
	GeeHashMap* _tmp209_;
	AdwActionRow* _tmp210_;
	gulong _tmp211_;
	AdwActionRow* _tmp212_;
	AdwActionRow* tweet_us_row = NULL;
	AdwActionRow* _tmp213_;
	AdwActionRow* _tmp214_;
	AdwActionRow* _tmp215_;
	GtkWidget* _tmp216_;
	GtkWidget* _tmp217_;
	AdwActionRow* _tmp218_;
	GtkWidget* _tmp219_;
	GtkWidget* _tmp220_;
	AdwActionRow* _tmp221_;
	AdwActionRow* _tmp222_;
	GeeHashMap* _tmp223_;
	AdwActionRow* _tmp224_;
	gulong _tmp225_;
	AdwActionRow* _tmp226_;
	AdwActionRow* discord_row = NULL;
	AdwActionRow* _tmp227_;
	AdwActionRow* _tmp228_;
	AdwActionRow* _tmp229_;
	GtkWidget* _tmp230_;
	GtkWidget* _tmp231_;
	AdwActionRow* _tmp232_;
	GtkWidget* _tmp233_;
	GtkWidget* _tmp234_;
	AdwActionRow* _tmp235_;
	AdwActionRow* _tmp236_;
	GeeHashMap* _tmp237_;
	AdwActionRow* _tmp238_;
	gulong _tmp239_;
	AdwActionRow* _tmp240_;
	AdwActionRow* mastodon_row = NULL;
	AdwActionRow* _tmp241_;
	AdwActionRow* _tmp242_;
	AdwActionRow* _tmp243_;
	GtkWidget* _tmp244_;
	GtkWidget* _tmp245_;
	AdwActionRow* _tmp246_;
	GtkWidget* _tmp247_;
	GtkWidget* _tmp248_;
	AdwActionRow* _tmp249_;
	AdwActionRow* _tmp250_;
	GeeHashMap* _tmp251_;
	AdwActionRow* _tmp252_;
	gulong _tmp253_;
	AdwActionRow* _tmp254_;
	AdwPreferencesGroup* _tmp255_;
	AdwActionRow* _tmp256_;
	AdwPreferencesGroup* _tmp257_;
	AdwActionRow* _tmp258_;
	AdwPreferencesGroup* _tmp259_;
	AdwActionRow* _tmp260_;
	AdwPreferencesGroup* _tmp261_;
	AdwActionRow* _tmp262_;
	AdwPreferencesPage* _tmp263_;
	AdwPreferencesGroup* _tmp264_;
	AdwPreferencesGroup* privacy_group = NULL;
	AdwPreferencesGroup* _tmp265_;
	AdwPreferencesGroup* _tmp266_;
	AdwActionRow* privacy_policy_row = NULL;
	AdwActionRow* _tmp267_;
	AdwActionRow* _tmp268_;
	AdwActionRow* _tmp269_;
	GtkWidget* _tmp270_;
	GtkWidget* _tmp271_;
	AdwActionRow* _tmp272_;
	GtkWidget* _tmp273_;
	GtkWidget* _tmp274_;
	AdwActionRow* _tmp275_;
	AdwActionRow* _tmp276_;
	AdwActionRow* delete_row = NULL;
	AdwActionRow* _tmp277_;
	AdwActionRow* _tmp278_;
	AdwActionRow* _tmp279_;
	GtkWidget* _tmp280_;
	GtkWidget* _tmp281_;
	AdwActionRow* _tmp282_;
	GtkWidget* _tmp283_;
	GtkWidget* _tmp284_;
	AdwActionRow* _tmp285_;
	AdwPreferencesGroup* _tmp286_;
	AdwActionRow* _tmp287_;
	AdwPreferencesGroup* _tmp288_;
	AdwActionRow* _tmp289_;
	AdwPreferencesPage* _tmp290_;
	AdwPreferencesGroup* _tmp291_;
	GeeHashMap* _tmp292_;
	AdwActionRow* _tmp293_;
	gulong _tmp294_;
	AdwActionRow* _tmp295_;
	GeeHashMap* _tmp296_;
	AdwActionRow* _tmp297_;
	gulong _tmp298_;
	AdwActionRow* _tmp299_;
	GeeHashMap* _tmp300_;
	AdwActionRow* _tmp301_;
	gulong _tmp302_;
	AdwActionRow* _tmp303_;
	GeeHashMap* _tmp304_;
	AdwActionRow* _tmp305_;
	gulong _tmp306_;
	AdwActionRow* _tmp307_;
	AdwPreferencesPage* _tmp308_;
	ServicesEventBus* _tmp309_;
	ServicesEventBus* _tmp310_;
	GtkShortcut* shortcut = NULL;
	GtkKeyvalTrigger* _tmp311_;
	GtkCallbackAction* _tmp312_;
	GtkShortcut* _tmp313_;
	GtkShortcutController* _tmp314_;
	GtkShortcutController* _tmp315_;
	GtkShortcut* _tmp316_;
	GtkShortcut* _tmp317_;
	GtkShortcutController* _tmp318_;
	parent_class = G_OBJECT_CLASS (dialogs_preferences_preferences_window_parent_class);
	obj = parent_class->constructor (type, n_construct_properties, construct_properties);
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, DIALOGS_PREFERENCES_TYPE_PREFERENCES_WINDOW, DialogsPreferencesPreferencesWindow);
	_tmp0_ = (AdwPreferencesPage*) adw_preferences_page_new ();
	g_object_ref_sink (_tmp0_);
	page = _tmp0_;
	_tmp1_ = page;
	adw_preferences_page_set_title (_tmp1_, _ ("Preferences"));
	_tmp2_ = page;
	adw_preferences_page_set_name (_tmp2_, "preferences");
	_tmp3_ = page;
	adw_preferences_page_set_icon_name (_tmp3_, "applications-system-symbolic");
	_tmp4_ = (AdwActionRow*) adw_action_row_new ();
	g_object_ref_sink (_tmp4_);
	accounts_row = _tmp4_;
	_tmp5_ = accounts_row;
	gtk_list_box_row_set_activatable ((GtkListBoxRow*) _tmp5_, TRUE);
	_tmp6_ = accounts_row;
	_tmp7_ = dialogs_preferences_preferences_window_generate_icon (self, "cloud-outline-thick-symbolic", 16);
	_tmp8_ = _tmp7_;
	adw_action_row_add_prefix (_tmp6_, _tmp8_);
	_g_object_unref0 (_tmp8_);
	_tmp9_ = accounts_row;
	_tmp10_ = dialogs_preferences_preferences_window_generate_icon (self, "go-next-symbolic", 16);
	_tmp11_ = _tmp10_;
	adw_action_row_add_suffix (_tmp9_, _tmp11_);
	_g_object_unref0 (_tmp11_);
	_tmp12_ = accounts_row;
	adw_preferences_row_set_title ((AdwPreferencesRow*) _tmp12_, _ ("Accounts"));
	_tmp13_ = accounts_row;
	adw_action_row_set_subtitle (_tmp13_, _ ("Sync your favorite to-do providers"));
	_tmp14_ = self->signal_map;
	_tmp15_ = accounts_row;
	_tmp16_ = g_signal_connect_object (_tmp15_, "activated", (GCallback) __dialogs_preferences_preferences_window___lambda432__adw_action_row_activated, self, 0);
	_tmp17_ = accounts_row;
	gee_abstract_map_set ((GeeAbstractMap*) _tmp14_, (gpointer) ((guintptr) _tmp16_), (GObject*) _tmp17_);
	_tmp18_ = (AdwPreferencesGroup*) adw_preferences_group_new ();
	g_object_ref_sink (_tmp18_);
	accounts_group = _tmp18_;
	_tmp19_ = accounts_group;
	_tmp20_ = accounts_row;
	adw_preferences_group_add (_tmp19_, (GtkWidget*) _tmp20_);
	_tmp21_ = page;
	_tmp22_ = accounts_group;
	adw_preferences_page_add (_tmp21_, _tmp22_);
	_tmp23_ = g_strdup (_ ("Home View"));
	_tmp24_ = g_strdup (_ ("Set the view shown at first launch"));
	_tmp25_ = (AdwActionRow*) adw_action_row_new ();
	gtk_list_box_row_set_activatable ((GtkListBoxRow*) _tmp25_, TRUE);
	adw_preferences_row_set_title ((AdwPreferencesRow*) _tmp25_, _tmp23_);
	_g_free0 (_tmp23_);
	adw_action_row_set_subtitle (_tmp25_, _tmp24_);
	_g_free0 (_tmp24_);
	g_object_ref_sink (_tmp25_);
	home_page_row = _tmp25_;
	_tmp26_ = home_page_row;
	_tmp27_ = dialogs_preferences_preferences_window_generate_icon (self, "go-home-symbolic", 16);
	_tmp28_ = _tmp27_;
	adw_action_row_add_prefix (_tmp26_, _tmp28_);
	_g_object_unref0 (_tmp28_);
	_tmp29_ = home_page_row;
	_tmp30_ = dialogs_preferences_preferences_window_generate_icon (self, "go-next-symbolic", 16);
	_tmp31_ = _tmp30_;
	adw_action_row_add_suffix (_tmp29_, _tmp31_);
	_g_object_unref0 (_tmp31_);
	_tmp32_ = self->signal_map;
	_tmp33_ = home_page_row;
	_tmp34_ = g_signal_connect_object (_tmp33_, "activated", (GCallback) __dialogs_preferences_preferences_window___lambda433__adw_action_row_activated, self, 0);
	_tmp35_ = home_page_row;
	gee_abstract_map_set ((GeeAbstractMap*) _tmp32_, (gpointer) ((guintptr) _tmp34_), (GObject*) _tmp35_);
	_tmp36_ = (AdwActionRow*) adw_action_row_new ();
	g_object_ref_sink (_tmp36_);
	general_row = _tmp36_;
	_tmp37_ = general_row;
	gtk_list_box_row_set_activatable ((GtkListBoxRow*) _tmp37_, TRUE);
	_tmp38_ = general_row;
	_tmp39_ = dialogs_preferences_preferences_window_generate_icon (self, "settings-symbolic", 16);
	_tmp40_ = _tmp39_;
	adw_action_row_add_prefix (_tmp38_, _tmp40_);
	_g_object_unref0 (_tmp40_);
	_tmp41_ = general_row;
	_tmp42_ = dialogs_preferences_preferences_window_generate_icon (self, "go-next-symbolic", 16);
	_tmp43_ = _tmp42_;
	adw_action_row_add_suffix (_tmp41_, _tmp43_);
	_g_object_unref0 (_tmp43_);
	_tmp44_ = general_row;
	adw_preferences_row_set_title ((AdwPreferencesRow*) _tmp44_, _ ("General"));
	_tmp45_ = general_row;
	adw_action_row_set_subtitle (_tmp45_, _ ("Customize to your liking"));
	_tmp46_ = self->signal_map;
	_tmp47_ = general_row;
	_tmp48_ = g_signal_connect_object (_tmp47_, "activated", (GCallback) __dialogs_preferences_preferences_window___lambda434__adw_action_row_activated, self, 0);
	_tmp49_ = general_row;
	gee_abstract_map_set ((GeeAbstractMap*) _tmp46_, (gpointer) ((guintptr) _tmp48_), (GObject*) _tmp49_);
	_tmp50_ = (AdwActionRow*) adw_action_row_new ();
	g_object_ref_sink (_tmp50_);
	task_setting_row = _tmp50_;
	_tmp51_ = task_setting_row;
	gtk_list_box_row_set_activatable ((GtkListBoxRow*) _tmp51_, TRUE);
	_tmp52_ = task_setting_row;
	_tmp53_ = dialogs_preferences_preferences_window_generate_icon (self, "check-round-outline-symbolic", 16);
	_tmp54_ = _tmp53_;
	adw_action_row_add_prefix (_tmp52_, _tmp54_);
	_g_object_unref0 (_tmp54_);
	_tmp55_ = task_setting_row;
	_tmp56_ = dialogs_preferences_preferences_window_generate_icon (self, "go-next-symbolic", 16);
	_tmp57_ = _tmp56_;
	adw_action_row_add_suffix (_tmp55_, _tmp57_);
	_g_object_unref0 (_tmp57_);
	_tmp58_ = task_setting_row;
	adw_preferences_row_set_title ((AdwPreferencesRow*) _tmp58_, _ ("Task Settings"));
	_tmp59_ = self->signal_map;
	_tmp60_ = task_setting_row;
	_tmp61_ = g_signal_connect_object (_tmp60_, "activated", (GCallback) __dialogs_preferences_preferences_window___lambda435__adw_action_row_activated, self, 0);
	_tmp62_ = task_setting_row;
	gee_abstract_map_set ((GeeAbstractMap*) _tmp59_, (gpointer) ((guintptr) _tmp61_), (GObject*) _tmp62_);
	_tmp63_ = (AdwActionRow*) adw_action_row_new ();
	g_object_ref_sink (_tmp63_);
	sidebar_row = _tmp63_;
	_tmp64_ = sidebar_row;
	gtk_list_box_row_set_activatable ((GtkListBoxRow*) _tmp64_, TRUE);
	_tmp65_ = sidebar_row;
	_tmp66_ = dialogs_preferences_preferences_window_generate_icon (self, "dock-left-symbolic", 16);
	_tmp67_ = _tmp66_;
	adw_action_row_add_prefix (_tmp65_, _tmp67_);
	_g_object_unref0 (_tmp67_);
	_tmp68_ = sidebar_row;
	_tmp69_ = dialogs_preferences_preferences_window_generate_icon (self, "go-next-symbolic", 16);
	_tmp70_ = _tmp69_;
	adw_action_row_add_suffix (_tmp68_, _tmp70_);
	_g_object_unref0 (_tmp70_);
	_tmp71_ = sidebar_row;
	adw_preferences_row_set_title ((AdwPreferencesRow*) _tmp71_, _ ("Sidebar"));
	_tmp72_ = sidebar_row;
	adw_action_row_set_subtitle (_tmp72_, _ ("Customize your sidebar"));
	_tmp73_ = self->signal_map;
	_tmp74_ = sidebar_row;
	_tmp75_ = g_signal_connect_object (_tmp74_, "activated", (GCallback) __dialogs_preferences_preferences_window___lambda436__adw_action_row_activated, self, 0);
	_tmp76_ = sidebar_row;
	gee_abstract_map_set ((GeeAbstractMap*) _tmp73_, (gpointer) ((guintptr) _tmp75_), (GObject*) _tmp76_);
	_tmp77_ = (AdwActionRow*) adw_action_row_new ();
	g_object_ref_sink (_tmp77_);
	appearance_row = _tmp77_;
	_tmp78_ = appearance_row;
	gtk_list_box_row_set_activatable ((GtkListBoxRow*) _tmp78_, TRUE);
	_tmp79_ = appearance_row;
	_tmp80_ = dialogs_preferences_preferences_window_generate_icon (self, "color-symbolic", 16);
	_tmp81_ = _tmp80_;
	adw_action_row_add_prefix (_tmp79_, _tmp81_);
	_g_object_unref0 (_tmp81_);
	_tmp82_ = appearance_row;
	_tmp83_ = dialogs_preferences_preferences_window_generate_icon (self, "go-next-symbolic", 16);
	_tmp84_ = _tmp83_;
	adw_action_row_add_suffix (_tmp82_, _tmp84_);
	_g_object_unref0 (_tmp84_);
	_tmp85_ = appearance_row;
	adw_preferences_row_set_title ((AdwPreferencesRow*) _tmp85_, _ ("Appearance"));
	_tmp86_ = appearance_row;
	_tmp87_ = util_get_default ();
	_tmp88_ = _tmp87_;
	_tmp89_ = util_get_theme_name (_tmp88_);
	_tmp90_ = _tmp89_;
	adw_action_row_set_subtitle (_tmp86_, _tmp90_);
	_g_free0 (_tmp90_);
	_g_object_unref0 (_tmp88_);
	_tmp91_ = self->signal_map;
	_tmp92_ = appearance_row;
	_tmp93_ = g_signal_connect_object (_tmp92_, "activated", (GCallback) __dialogs_preferences_preferences_window___lambda437__adw_action_row_activated, self, 0);
	_tmp94_ = appearance_row;
	gee_abstract_map_set ((GeeAbstractMap*) _tmp91_, (gpointer) ((guintptr) _tmp93_), (GObject*) _tmp94_);
	_tmp95_ = (AdwActionRow*) adw_action_row_new ();
	g_object_ref_sink (_tmp95_);
	quick_add_row = _tmp95_;
	_tmp96_ = quick_add_row;
	gtk_list_box_row_set_activatable ((GtkListBoxRow*) _tmp96_, TRUE);
	_tmp97_ = quick_add_row;
	_tmp98_ = dialogs_preferences_preferences_window_generate_icon (self, "tab-new-symbolic", 16);
	_tmp99_ = _tmp98_;
	adw_action_row_add_prefix (_tmp97_, _tmp99_);
	_g_object_unref0 (_tmp99_);
	_tmp100_ = quick_add_row;
	_tmp101_ = dialogs_preferences_preferences_window_generate_icon (self, "go-next-symbolic", 16);
	_tmp102_ = _tmp101_;
	adw_action_row_add_suffix (_tmp100_, _tmp102_);
	_g_object_unref0 (_tmp102_);
	_tmp103_ = quick_add_row;
	adw_preferences_row_set_title ((AdwPreferencesRow*) _tmp103_, _ ("Quick Add"));
	_tmp104_ = quick_add_row;
	adw_action_row_set_subtitle (_tmp104_, _ ("Adding to-do's from anywhere"));
	_tmp105_ = self->signal_map;
	_tmp106_ = quick_add_row;
	_tmp107_ = g_signal_connect_object (_tmp106_, "activated", (GCallback) __dialogs_preferences_preferences_window___lambda438__adw_action_row_activated, self, 0);
	_tmp108_ = quick_add_row;
	gee_abstract_map_set ((GeeAbstractMap*) _tmp105_, (gpointer) ((guintptr) _tmp107_), (GObject*) _tmp108_);
	_tmp109_ = (AdwActionRow*) adw_action_row_new ();
	g_object_ref_sink (_tmp109_);
	backups_row = _tmp109_;
	_tmp110_ = backups_row;
	gtk_list_box_row_set_activatable ((GtkListBoxRow*) _tmp110_, TRUE);
	_tmp111_ = backups_row;
	_tmp112_ = dialogs_preferences_preferences_window_generate_icon (self, "arrow3-down-symbolic", 16);
	_tmp113_ = _tmp112_;
	adw_action_row_add_prefix (_tmp111_, _tmp113_);
	_g_object_unref0 (_tmp113_);
	_tmp114_ = backups_row;
	_tmp115_ = dialogs_preferences_preferences_window_generate_icon (self, "go-next-symbolic", 16);
	_tmp116_ = _tmp115_;
	adw_action_row_add_suffix (_tmp114_, _tmp116_);
	_g_object_unref0 (_tmp116_);
	_tmp117_ = backups_row;
	adw_preferences_row_set_title ((AdwPreferencesRow*) _tmp117_, _ ("Backups"));
	_tmp118_ = backups_row;
	adw_action_row_set_subtitle (_tmp118_, _ ("Backup or migrate from Planner."));
	_tmp119_ = (AdwActionRow*) adw_action_row_new ();
	g_object_ref_sink (_tmp119_);
	tutorial_row = _tmp119_;
	_tmp120_ = tutorial_row;
	gtk_list_box_row_set_activatable ((GtkListBoxRow*) _tmp120_, TRUE);
	_tmp121_ = tutorial_row;
	_tmp122_ = dialogs_preferences_preferences_window_generate_icon (self, "rescue-symbolic", 16);
	_tmp123_ = _tmp122_;
	adw_action_row_add_prefix (_tmp121_, _tmp123_);
	_g_object_unref0 (_tmp123_);
	_tmp124_ = tutorial_row;
	_tmp125_ = dialogs_preferences_preferences_window_generate_icon (self, "go-next-symbolic", 16);
	_tmp126_ = _tmp125_;
	adw_action_row_add_suffix (_tmp124_, _tmp126_);
	_g_object_unref0 (_tmp126_);
	_tmp127_ = tutorial_row;
	adw_preferences_row_set_title ((AdwPreferencesRow*) _tmp127_, _ ("Create Tutorial Project"));
	_tmp128_ = tutorial_row;
	adw_action_row_set_subtitle (_tmp128_, _ ("Learn the app step by step with a short tutorial project"));
	_tmp129_ = (AdwPreferencesGroup*) adw_preferences_group_new ();
	g_object_ref_sink (_tmp129_);
	personalization_group = _tmp129_;
	_tmp130_ = personalization_group;
	_tmp131_ = home_page_row;
	adw_preferences_group_add (_tmp130_, (GtkWidget*) _tmp131_);
	_tmp132_ = personalization_group;
	_tmp133_ = general_row;
	adw_preferences_group_add (_tmp132_, (GtkWidget*) _tmp133_);
	_tmp134_ = personalization_group;
	_tmp135_ = task_setting_row;
	adw_preferences_group_add (_tmp134_, (GtkWidget*) _tmp135_);
	_tmp136_ = personalization_group;
	_tmp137_ = sidebar_row;
	adw_preferences_group_add (_tmp136_, (GtkWidget*) _tmp137_);
	_tmp138_ = personalization_group;
	_tmp139_ = appearance_row;
	adw_preferences_group_add (_tmp138_, (GtkWidget*) _tmp139_);
	_tmp140_ = personalization_group;
	_tmp141_ = quick_add_row;
	adw_preferences_group_add (_tmp140_, (GtkWidget*) _tmp141_);
	_tmp142_ = personalization_group;
	_tmp143_ = backups_row;
	adw_preferences_group_add (_tmp142_, (GtkWidget*) _tmp143_);
	_tmp144_ = personalization_group;
	_tmp145_ = tutorial_row;
	adw_preferences_group_add (_tmp144_, (GtkWidget*) _tmp145_);
	_tmp146_ = page;
	_tmp147_ = personalization_group;
	adw_preferences_page_add (_tmp146_, _tmp147_);
	_tmp148_ = (AdwActionRow*) adw_action_row_new ();
	g_object_ref_sink (_tmp148_);
	supporting_us_row = _tmp148_;
	_tmp149_ = supporting_us_row;
	gtk_list_box_row_set_activatable ((GtkListBoxRow*) _tmp149_, TRUE);
	_tmp150_ = supporting_us_row;
	_tmp151_ = dialogs_preferences_preferences_window_generate_icon (self, "heart-outline-thick-symbolic", 16);
	_tmp152_ = _tmp151_;
	adw_action_row_add_prefix (_tmp150_, _tmp152_);
	_g_object_unref0 (_tmp152_);
	_tmp153_ = supporting_us_row;
	_tmp154_ = dialogs_preferences_preferences_window_generate_icon (self, "go-next-symbolic", 16);
	_tmp155_ = _tmp154_;
	adw_action_row_add_suffix (_tmp153_, _tmp155_);
	_g_object_unref0 (_tmp155_);
	_tmp156_ = supporting_us_row;
	adw_preferences_row_set_title ((AdwPreferencesRow*) _tmp156_, _ ("Donate"));
	_tmp157_ = supporting_us_row;
	adw_action_row_set_subtitle (_tmp157_, _ ("Want to buy me a drink?"));
	_tmp158_ = self->signal_map;
	_tmp159_ = supporting_us_row;
	_tmp160_ = g_signal_connect_object (_tmp159_, "activated", (GCallback) __dialogs_preferences_preferences_window___lambda439__adw_action_row_activated, self, 0);
	_tmp161_ = supporting_us_row;
	gee_abstract_map_set ((GeeAbstractMap*) _tmp158_, (gpointer) ((guintptr) _tmp160_), (GObject*) _tmp161_);
	_tmp162_ = (AdwActionRow*) adw_action_row_new ();
	g_object_ref_sink (_tmp162_);
	issue_row = _tmp162_;
	_tmp163_ = issue_row;
	gtk_list_box_row_set_activatable ((GtkListBoxRow*) _tmp163_, TRUE);
	_tmp164_ = issue_row;
	_tmp165_ = dialogs_preferences_preferences_window_generate_icon (self, "lightbulb-symbolic", 16);
	_tmp166_ = _tmp165_;
	adw_action_row_add_prefix (_tmp164_, _tmp166_);
	_g_object_unref0 (_tmp166_);
	_tmp167_ = issue_row;
	_tmp168_ = dialogs_preferences_preferences_window_generate_icon (self, "go-next-symbolic", 16);
	_tmp169_ = _tmp168_;
	adw_action_row_add_suffix (_tmp167_, _tmp169_);
	_g_object_unref0 (_tmp169_);
	_tmp170_ = issue_row;
	adw_preferences_row_set_title ((AdwPreferencesRow*) _tmp170_, _ ("Report Issue or Request Feature"));
	_tmp171_ = issue_row;
	adw_action_row_set_subtitle (_tmp171_, _ ("Share bugs or ideas on GitHub"));
	_tmp172_ = self->signal_map;
	_tmp173_ = issue_row;
	_tmp174_ = g_signal_connect_object (_tmp173_, "activated", (GCallback) __dialogs_preferences_preferences_window___lambda440__adw_action_row_activated, self, 0);
	_tmp175_ = issue_row;
	gee_abstract_map_set ((GeeAbstractMap*) _tmp172_, (gpointer) ((guintptr) _tmp174_), (GObject*) _tmp175_);
	_tmp176_ = widgets_translation_row_new ();
	g_object_ref_sink (_tmp176_);
	translation_row = _tmp176_;
	_tmp177_ = translation_row;
	widgets_translation_row_set_icon_name (_tmp177_, "language-symbolic");
	_tmp178_ = translation_row;
	dialogs_preferences_preferences_window_setup_visibility_detection (self, _tmp178_);
	_tmp179_ = (GtkGestureClick*) gtk_gesture_click_new ();
	click_gesture = _tmp179_;
	_tmp180_ = translation_row;
	_tmp181_ = click_gesture;
	_tmp182_ = _g_object_ref0 ((GtkEventController*) _tmp181_);
	gtk_widget_add_controller ((GtkWidget*) _tmp180_, _tmp182_);
	_tmp183_ = self->signal_map;
	_tmp184_ = click_gesture;
	_tmp185_ = g_signal_connect_object (_tmp184_, "pressed", (GCallback) __dialogs_preferences_preferences_window___lambda441__gtk_gesture_click_pressed, self, 0);
	_tmp186_ = click_gesture;
	gee_abstract_map_set ((GeeAbstractMap*) _tmp183_, (gpointer) ((guintptr) _tmp185_), (GObject*) _tmp186_);
	_tmp187_ = (AdwPreferencesGroup*) adw_preferences_group_new ();
	g_object_ref_sink (_tmp187_);
	collaboration_group = _tmp187_;
	_tmp188_ = collaboration_group;
	adw_preferences_group_set_title (_tmp188_, _ ("Get Involved"));
	_tmp189_ = collaboration_group;
	_tmp190_ = supporting_us_row;
	adw_preferences_group_add (_tmp189_, (GtkWidget*) _tmp190_);
	_tmp191_ = collaboration_group;
	_tmp192_ = issue_row;
	adw_preferences_group_add (_tmp191_, (GtkWidget*) _tmp192_);
	_tmp193_ = collaboration_group;
	_tmp194_ = translation_row;
	adw_preferences_group_add (_tmp193_, (GtkWidget*) _tmp194_);
	_tmp195_ = page;
	_tmp196_ = collaboration_group;
	adw_preferences_page_add (_tmp195_, _tmp196_);
	_tmp197_ = (AdwPreferencesGroup*) adw_preferences_group_new ();
	g_object_ref_sink (_tmp197_);
	reach_us_group = _tmp197_;
	_tmp198_ = reach_us_group;
	adw_preferences_group_set_title (_tmp198_, _ ("Reach Us"));
	_tmp199_ = (AdwActionRow*) adw_action_row_new ();
	g_object_ref_sink (_tmp199_);
	contact_us_row = _tmp199_;
	_tmp200_ = contact_us_row;
	gtk_list_box_row_set_activatable ((GtkListBoxRow*) _tmp200_, TRUE);
	_tmp201_ = contact_us_row;
	_tmp202_ = dialogs_preferences_preferences_window_generate_icon (self, "mail-symbolic", 16);
	_tmp203_ = _tmp202_;
	adw_action_row_add_prefix (_tmp201_, _tmp203_);
	_g_object_unref0 (_tmp203_);
	_tmp204_ = contact_us_row;
	_tmp205_ = dialogs_preferences_preferences_window_generate_icon (self, "go-next-symbolic", 16);
	_tmp206_ = _tmp205_;
	adw_action_row_add_suffix (_tmp204_, _tmp206_);
	_g_object_unref0 (_tmp206_);
	_tmp207_ = contact_us_row;
	adw_preferences_row_set_title ((AdwPreferencesRow*) _tmp207_, _ ("Contact Us"));
	_tmp208_ = contact_us_row;
	adw_action_row_set_subtitle (_tmp208_, _ ("Request a feature or ask us anything"));
	_tmp209_ = self->signal_map;
	_tmp210_ = contact_us_row;
	_tmp211_ = g_signal_connect_object (_tmp210_, "activated", (GCallback) __dialogs_preferences_preferences_window___lambda442__adw_action_row_activated, self, 0);
	_tmp212_ = contact_us_row;
	gee_abstract_map_set ((GeeAbstractMap*) _tmp209_, (gpointer) ((guintptr) _tmp211_), (GObject*) _tmp212_);
	_tmp213_ = (AdwActionRow*) adw_action_row_new ();
	g_object_ref_sink (_tmp213_);
	tweet_us_row = _tmp213_;
	_tmp214_ = tweet_us_row;
	gtk_list_box_row_set_activatable ((GtkListBoxRow*) _tmp214_, TRUE);
	_tmp215_ = tweet_us_row;
	_tmp216_ = dialogs_preferences_preferences_window_generate_icon (self, "chat-bubble-text-symbolic", 16);
	_tmp217_ = _tmp216_;
	adw_action_row_add_prefix (_tmp215_, _tmp217_);
	_g_object_unref0 (_tmp217_);
	_tmp218_ = tweet_us_row;
	_tmp219_ = dialogs_preferences_preferences_window_generate_icon (self, "go-next-symbolic", 16);
	_tmp220_ = _tmp219_;
	adw_action_row_add_suffix (_tmp218_, _tmp220_);
	_g_object_unref0 (_tmp220_);
	_tmp221_ = tweet_us_row;
	adw_preferences_row_set_title ((AdwPreferencesRow*) _tmp221_, _ ("Tweet Us"));
	_tmp222_ = tweet_us_row;
	adw_action_row_set_subtitle (_tmp222_, _ ("Share some love"));
	_tmp223_ = self->signal_map;
	_tmp224_ = tweet_us_row;
	_tmp225_ = g_signal_connect_object (_tmp224_, "activated", (GCallback) __dialogs_preferences_preferences_window___lambda443__adw_action_row_activated, self, 0);
	_tmp226_ = tweet_us_row;
	gee_abstract_map_set ((GeeAbstractMap*) _tmp223_, (gpointer) ((guintptr) _tmp225_), (GObject*) _tmp226_);
	_tmp227_ = (AdwActionRow*) adw_action_row_new ();
	g_object_ref_sink (_tmp227_);
	discord_row = _tmp227_;
	_tmp228_ = discord_row;
	gtk_list_box_row_set_activatable ((GtkListBoxRow*) _tmp228_, TRUE);
	_tmp229_ = discord_row;
	_tmp230_ = dialogs_preferences_preferences_window_generate_icon (self, "navigate-symbolic", 16);
	_tmp231_ = _tmp230_;
	adw_action_row_add_prefix (_tmp229_, _tmp231_);
	_g_object_unref0 (_tmp231_);
	_tmp232_ = discord_row;
	_tmp233_ = dialogs_preferences_preferences_window_generate_icon (self, "go-next-symbolic", 16);
	_tmp234_ = _tmp233_;
	adw_action_row_add_suffix (_tmp232_, _tmp234_);
	_g_object_unref0 (_tmp234_);
	_tmp235_ = discord_row;
	adw_preferences_row_set_title ((AdwPreferencesRow*) _tmp235_, _ ("Discord"));
	_tmp236_ = discord_row;
	adw_action_row_set_subtitle (_tmp236_, _ ("Discuss and share your feedback"));
	_tmp237_ = self->signal_map;
	_tmp238_ = discord_row;
	_tmp239_ = g_signal_connect_object (_tmp238_, "activated", (GCallback) __dialogs_preferences_preferences_window___lambda444__adw_action_row_activated, self, 0);
	_tmp240_ = discord_row;
	gee_abstract_map_set ((GeeAbstractMap*) _tmp237_, (gpointer) ((guintptr) _tmp239_), (GObject*) _tmp240_);
	_tmp241_ = (AdwActionRow*) adw_action_row_new ();
	g_object_ref_sink (_tmp241_);
	mastodon_row = _tmp241_;
	_tmp242_ = mastodon_row;
	gtk_list_box_row_set_activatable ((GtkListBoxRow*) _tmp242_, TRUE);
	_tmp243_ = mastodon_row;
	_tmp244_ = dialogs_preferences_preferences_window_generate_icon (self, "external-link-symbolic", 16);
	_tmp245_ = _tmp244_;
	adw_action_row_add_prefix (_tmp243_, _tmp245_);
	_g_object_unref0 (_tmp245_);
	_tmp246_ = mastodon_row;
	_tmp247_ = dialogs_preferences_preferences_window_generate_icon (self, "go-next-symbolic", 16);
	_tmp248_ = _tmp247_;
	adw_action_row_add_suffix (_tmp246_, _tmp248_);
	_g_object_unref0 (_tmp248_);
	_tmp249_ = mastodon_row;
	adw_preferences_row_set_title ((AdwPreferencesRow*) _tmp249_, _ ("Mastodon"));
	_tmp250_ = mastodon_row;
	adw_action_row_set_subtitle (_tmp250_, _ ("Share some love"));
	_tmp251_ = self->signal_map;
	_tmp252_ = mastodon_row;
	_tmp253_ = g_signal_connect_object (_tmp252_, "activated", (GCallback) __dialogs_preferences_preferences_window___lambda445__adw_action_row_activated, self, 0);
	_tmp254_ = mastodon_row;
	gee_abstract_map_set ((GeeAbstractMap*) _tmp251_, (gpointer) ((guintptr) _tmp253_), (GObject*) _tmp254_);
	_tmp255_ = reach_us_group;
	_tmp256_ = contact_us_row;
	adw_preferences_group_add (_tmp255_, (GtkWidget*) _tmp256_);
	_tmp257_ = reach_us_group;
	_tmp258_ = mastodon_row;
	adw_preferences_group_add (_tmp257_, (GtkWidget*) _tmp258_);
	_tmp259_ = reach_us_group;
	_tmp260_ = tweet_us_row;
	adw_preferences_group_add (_tmp259_, (GtkWidget*) _tmp260_);
	_tmp261_ = reach_us_group;
	_tmp262_ = discord_row;
	adw_preferences_group_add (_tmp261_, (GtkWidget*) _tmp262_);
	_tmp263_ = page;
	_tmp264_ = reach_us_group;
	adw_preferences_page_add (_tmp263_, _tmp264_);
	_tmp265_ = (AdwPreferencesGroup*) adw_preferences_group_new ();
	g_object_ref_sink (_tmp265_);
	privacy_group = _tmp265_;
	_tmp266_ = privacy_group;
	adw_preferences_group_set_title (_tmp266_, _ ("Privacy"));
	_tmp267_ = (AdwActionRow*) adw_action_row_new ();
	g_object_ref_sink (_tmp267_);
	privacy_policy_row = _tmp267_;
	_tmp268_ = privacy_policy_row;
	gtk_list_box_row_set_activatable ((GtkListBoxRow*) _tmp268_, TRUE);
	_tmp269_ = privacy_policy_row;
	_tmp270_ = dialogs_preferences_preferences_window_generate_icon (self, "shield-safe-symbolic", 16);
	_tmp271_ = _tmp270_;
	adw_action_row_add_prefix (_tmp269_, _tmp271_);
	_g_object_unref0 (_tmp271_);
	_tmp272_ = privacy_policy_row;
	_tmp273_ = dialogs_preferences_preferences_window_generate_icon (self, "go-next-symbolic", 16);
	_tmp274_ = _tmp273_;
	adw_action_row_add_suffix (_tmp272_, _tmp274_);
	_g_object_unref0 (_tmp274_);
	_tmp275_ = privacy_policy_row;
	adw_preferences_row_set_title ((AdwPreferencesRow*) _tmp275_, _ ("Privacy Policy"));
	_tmp276_ = privacy_policy_row;
	adw_action_row_set_subtitle (_tmp276_, _ ("We have nothing on you"));
	_tmp277_ = (AdwActionRow*) adw_action_row_new ();
	g_object_ref_sink (_tmp277_);
	delete_row = _tmp277_;
	_tmp278_ = delete_row;
	gtk_list_box_row_set_activatable ((GtkListBoxRow*) _tmp278_, TRUE);
	_tmp279_ = delete_row;
	_tmp280_ = dialogs_preferences_preferences_window_generate_icon (self, "user-trash-symbolic", 16);
	_tmp281_ = _tmp280_;
	adw_action_row_add_prefix (_tmp279_, _tmp281_);
	_g_object_unref0 (_tmp281_);
	_tmp282_ = delete_row;
	_tmp283_ = dialogs_preferences_preferences_window_generate_icon (self, "go-next-symbolic", 16);
	_tmp284_ = _tmp283_;
	adw_action_row_add_suffix (_tmp282_, _tmp284_);
	_g_object_unref0 (_tmp284_);
	_tmp285_ = delete_row;
	adw_preferences_row_set_title ((AdwPreferencesRow*) _tmp285_, _ ("Delete App Data"));
	_tmp286_ = privacy_group;
	_tmp287_ = privacy_policy_row;
	adw_preferences_group_add (_tmp286_, (GtkWidget*) _tmp287_);
	_tmp288_ = privacy_group;
	_tmp289_ = delete_row;
	adw_preferences_group_add (_tmp288_, (GtkWidget*) _tmp289_);
	_tmp290_ = page;
	_tmp291_ = privacy_group;
	adw_preferences_page_add (_tmp290_, _tmp291_);
	_tmp292_ = self->signal_map;
	_tmp293_ = tutorial_row;
	_tmp294_ = g_signal_connect_object (_tmp293_, "activated", (GCallback) __dialogs_preferences_preferences_window___lambda446__adw_action_row_activated, self, 0);
	_tmp295_ = tutorial_row;
	gee_abstract_map_set ((GeeAbstractMap*) _tmp292_, (gpointer) ((guintptr) _tmp294_), (GObject*) _tmp295_);
	_tmp296_ = self->signal_map;
	_tmp297_ = backups_row;
	_tmp298_ = g_signal_connect_object (_tmp297_, "activated", (GCallback) __dialogs_preferences_preferences_window___lambda447__adw_action_row_activated, self, 0);
	_tmp299_ = backups_row;
	gee_abstract_map_set ((GeeAbstractMap*) _tmp296_, (gpointer) ((guintptr) _tmp298_), (GObject*) _tmp299_);
	_tmp300_ = self->signal_map;
	_tmp301_ = privacy_policy_row;
	_tmp302_ = g_signal_connect_object (_tmp301_, "activated", (GCallback) __dialogs_preferences_preferences_window___lambda448__adw_action_row_activated, self, 0);
	_tmp303_ = privacy_policy_row;
	gee_abstract_map_set ((GeeAbstractMap*) _tmp300_, (gpointer) ((guintptr) _tmp302_), (GObject*) _tmp303_);
	_tmp304_ = self->signal_map;
	_tmp305_ = delete_row;
	_tmp306_ = g_signal_connect_object (_tmp305_, "activated", (GCallback) __dialogs_preferences_preferences_window___lambda449__adw_action_row_activated, self, 0);
	_tmp307_ = delete_row;
	gee_abstract_map_set ((GeeAbstractMap*) _tmp304_, (gpointer) ((guintptr) _tmp306_), (GObject*) _tmp307_);
	_tmp308_ = page;
	adw_preferences_dialog_add ((AdwPreferencesDialog*) self, _tmp308_);
	_tmp309_ = services_event_bus_get_default ();
	_tmp310_ = _tmp309_;
	g_signal_emit_by_name (_tmp310_, "disconnect-typing-accel");
	_g_object_unref0 (_tmp310_);
	_tmp311_ = (GtkKeyvalTrigger*) gtk_keyval_trigger_new (GDK_KEY_Escape, 0);
	_tmp312_ = (GtkCallbackAction*) gtk_callback_action_new (__dialogs_preferences_preferences_window___lambda450__gtk_shortcut_func, g_object_ref (self), g_object_unref);
	_tmp313_ = gtk_shortcut_new ((GtkShortcutTrigger*) _tmp311_, (GtkShortcutAction*) _tmp312_);
	shortcut = _tmp313_;
	_tmp314_ = (GtkShortcutController*) gtk_shortcut_controller_new ();
	_g_object_unref0 (self->priv->shortcut_controller);
	self->priv->shortcut_controller = _tmp314_;
	_tmp315_ = self->priv->shortcut_controller;
	_tmp316_ = shortcut;
	_tmp317_ = _g_object_ref0 (_tmp316_);
	gtk_shortcut_controller_add_shortcut (_tmp315_, _tmp317_);
	_tmp318_ = self->priv->shortcut_controller;
	G_TYPE_INSTANCE_GET_INTERFACE ((GtkShortcutManager*) self, gtk_shortcut_manager_get_type (), GtkShortcutManagerInterface)->add_controller ((GtkShortcutManager*) self, _tmp318_);
	g_signal_connect_object ((AdwDialog*) self, "closed", (GCallback) __dialogs_preferences_preferences_window___lambda451__adw_dialog_closed, self, 0);
	_g_object_unref0 (shortcut);
	_g_object_unref0 (delete_row);
	_g_object_unref0 (privacy_policy_row);
	_g_object_unref0 (privacy_group);
	_g_object_unref0 (mastodon_row);
	_g_object_unref0 (discord_row);
	_g_object_unref0 (tweet_us_row);
	_g_object_unref0 (contact_us_row);
	_g_object_unref0 (reach_us_group);
	_g_object_unref0 (collaboration_group);
	_g_object_unref0 (click_gesture);
	_g_object_unref0 (translation_row);
	_g_object_unref0 (issue_row);
	_g_object_unref0 (supporting_us_row);
	_g_object_unref0 (personalization_group);
	_g_object_unref0 (tutorial_row);
	_g_object_unref0 (backups_row);
	_g_object_unref0 (quick_add_row);
	_g_object_unref0 (appearance_row);
	_g_object_unref0 (sidebar_row);
	_g_object_unref0 (task_setting_row);
	_g_object_unref0 (general_row);
	_g_object_unref0 (home_page_row);
	_g_object_unref0 (accounts_group);
	_g_object_unref0 (accounts_row);
	_g_object_unref0 (page);
	return obj;
}

static void
dialogs_preferences_preferences_window_class_init (DialogsPreferencesPreferencesWindowClass * klass,
                                                   gpointer klass_data)
{
	dialogs_preferences_preferences_window_parent_class = g_type_class_peek_parent (klass);
	g_type_class_adjust_private_offset (klass, &DialogsPreferencesPreferencesWindow_private_offset);
	G_OBJECT_CLASS (klass)->constructor = dialogs_preferences_preferences_window_constructor;
	G_OBJECT_CLASS (klass)->finalize = dialogs_preferences_preferences_window_finalize;
}

static void
dialogs_preferences_preferences_window_instance_init (DialogsPreferencesPreferencesWindow * self,
                                                      gpointer klass)
{
	GeeHashMap* _tmp0_;
	GeeHashMap* _tmp1_;
	self->priv = dialogs_preferences_preferences_window_get_instance_private (self);
	_tmp0_ = gee_hash_map_new (G_TYPE_ULONG, NULL, NULL, G_TYPE_OBJECT, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL);
	self->signal_map = _tmp0_;
	_tmp1_ = gee_hash_map_new (G_TYPE_STRING, (GBoxedCopyFunc) g_strdup, (GDestroyNotify) g_free, DIALOGS_PREFERENCES_PAGES_TYPE_BASE_PAGE, (GBoxedCopyFunc) g_object_ref, (GDestroyNotify) g_object_unref, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL);
	self->priv->page_map = _tmp1_;
}

static void
dialogs_preferences_preferences_window_finalize (GObject * obj)
{
	DialogsPreferencesPreferencesWindow * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, DIALOGS_PREFERENCES_TYPE_PREFERENCES_WINDOW, DialogsPreferencesPreferencesWindow);
	g_debug ("PreferencesWindow.vala:35: Destroying - Dialogs.Preferences.Preference" \
"sWindow\n");
	_g_object_unref0 (self->signal_map);
	_g_object_unref0 (self->priv->page_map);
	_g_object_unref0 (self->priv->shortcut_controller);
	G_OBJECT_CLASS (dialogs_preferences_preferences_window_parent_class)->finalize (obj);
}

static GType
dialogs_preferences_preferences_window_get_type_once (void)
{
	static const GTypeInfo g_define_type_info = { sizeof (DialogsPreferencesPreferencesWindowClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) dialogs_preferences_preferences_window_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (DialogsPreferencesPreferencesWindow), 0, (GInstanceInitFunc) dialogs_preferences_preferences_window_instance_init, NULL };
	GType dialogs_preferences_preferences_window_type_id;
	dialogs_preferences_preferences_window_type_id = g_type_register_static (adw_preferences_dialog_get_type (), "DialogsPreferencesPreferencesWindow", &g_define_type_info, 0);
	DialogsPreferencesPreferencesWindow_private_offset = g_type_add_instance_private (dialogs_preferences_preferences_window_type_id, sizeof (DialogsPreferencesPreferencesWindowPrivate));
	return dialogs_preferences_preferences_window_type_id;
}

GType
dialogs_preferences_preferences_window_get_type (void)
{
	static volatile gsize dialogs_preferences_preferences_window_type_id__once = 0;
	if (g_once_init_enter (&dialogs_preferences_preferences_window_type_id__once)) {
		GType dialogs_preferences_preferences_window_type_id;
		dialogs_preferences_preferences_window_type_id = dialogs_preferences_preferences_window_get_type_once ();
		g_once_init_leave (&dialogs_preferences_preferences_window_type_id__once, dialogs_preferences_preferences_window_type_id);
	}
	return dialogs_preferences_preferences_window_type_id__once;
}

